# Table of Contents

<!-- toc -->

- [Plugin Manager](#plugin-manager)
- [Completion](#completion)
- [LSP](#lsp)
- [Treesitter](#treesitter)
- [Fuzzy Finder](#fuzzy-finder)
- [Filer](#filer)
- [Appearance](#appearance)
  * [Syntax / Highlight](#syntax--highlight)
  * [Statusline](#statusline)
  * [Bufferline](#bufferline)
  * [Tabline](#tabline)
  * [winbar](#winbar)
  * [statuscolumn](#statuscolumn)
  * [Cursor](#cursor)
  * [Cursorline / Columnline](#cursorline--columnline)
  * [Window Separators](#window-separators)
  * [Screen position](#screen-position)
  * [Wrap line](#wrap-line)
  * [Mode](#mode)
  * [Scrollbar](#scrollbar)
  * [Sidebar](#sidebar)
  * [Menu](#menu)
  * [Minimap](#minimap)
  * [Highlight current function](#highlight-current-function)
  * [listchars](#listchars)
  * [Background](#background)
- [Buffer, Window, Tab Management](#buffer-window-tab-management)
- [Terminal](#terminal)
- [Motion](#motion)
- [Jump](#jump)
- [Editing support](#editing-support)
  * [Select Edit](#select-edit)
  * [Insert](#insert)
    + [Smart Tab](#smart-tab)
  * [Auto Insert](#auto-insert)
  * [matchparen](#matchparen)
  * [Convert](#convert)
  * [Indent](#indent)
  * [Align](#align)
  * [TextObject, Operator](#textobject-operator)
  * [Parenthetical edit](#parenthetical-edit)
  * [Large file](#large-file)
  * [Misc](#misc)
- [Other Standard Feature Enhancement](#other-standard-feature-enhancement)
  * [Search, Replace, Select](#search-replace-select)
  * [Mapping](#mapping)
  * [Yank, Paste](#yank-paste)
  * [Split / Join](#split--join)
  * [Number](#number)
  * [Mark](#mark)
  * [Undo](#undo)
  * [Diff](#diff)
    + [Register](#register)
  * [Tags](#tags)
  * [Fold / Conceal](#fold--conceal)
  * [Calculation](#calculation)
  * [Command](#command)
  * [Command Line](#command-line)
  * [Spell check](#spell-check)
  * [Dictionary](#dictionary)
  * [digraph](#digraph)
  * [Abbreviation](#abbreviation)
  * [Quickfix / Location](#quickfix--location)
  * [cd(change directory)](#cdchange-directory)
    + [z](#z)
  * [ftdetect(Filetype detector)](#ftdetectfiletype-detector)
  * [ftplugin](#ftplugin)
    + [filetype colorscheme](#filetype-colorscheme)
  * [Encoding](#encoding)
  * [Macro](#macro)
  * [Errorformat](#errorformat)
  * [Message](#message)
  * [Help](#help)
  * [checkhealth](#checkhealth)
  * [Save&Backup](#savebackup)
  * [Startup](#startup)
  * [Session](#session)
  * [init.lua(vimrc)](#initluavimrc)
  * [Mouse](#mouse)
  * [Profiler](#profiler)
- [Coding](#coding)
  * [Reading assistant feature](#reading-assistant-feature)
    + [Current Position Info](#current-position-info)
  * [Comment Out](#comment-out)
    + [Context Header](#context-header)
  * [Linter / Formatter](#linter--formatter)
  * [Import](#import)
  * [Regex](#regex)
  * [Generate documentation](#generate-documentation)
  * [Code outline](#code-outline)
  * [Snippet/Template](#snippettemplate)
  * [Task Runner](#task-runner)
  * [Test](#test)
  * [Debug/REPL](#debugrepl)
  * [Git/GitHub](#gitgithub)
  * [Project](#project)
- [New features](#new-features)
  * [Note Taking](#note-taking)
  * [Diagram](#diagram)
  * [Translate](#translate)
  * [Manual](#manual)
  * [Popup Info](#popup-info)
  * [File Handling](#file-handling)
  * [Command Palette](#command-palette)
  * [Reload Configuration](#reload-configuration)
  * [Package Manager](#package-manager)
  * [Remote Development](#remote-development)
  * [Devcontainer](#devcontainer)
  * [Collaborative Editing](#collaborative-editing)
  * [Image](#image)
  * [Notification](#notification)
  * [Schedule](#schedule)
  * [Key stroke](#key-stroke)
  * [Concentration(Pomodoro/Zenn)](#concentrationpomodorozenn)
  * [Human-readable](#human-readable)
    + [bionic reading](#bionic-reading)
  * [Scratchpad](#scratchpad)
  * [Performance Test](#performance-test)
  * [Security](#security)
    + [Privacy](#privacy)
  * [Hex](#hex)
    + [Hex Editor](#hex-editor)
  * [Mail](#mail)
  * [Calendar](#calendar)
  * [Presentation](#presentation)
  * [EDITOR](#editor)
  * [Tutorial](#tutorial)
  * [Analytics](#analytics)
    + [Typing speed](#typing-speed)
  * [Market place](#market-place)
  * [RSS](#rss)
  * [IDE feature](#ide-feature)
    + [Code::Stats](#codestats)
  * [Update check](#update-check)
  * [Font](#font)
  * [Emoji](#emoji)
  * [Keyboard Layout](#keyboard-layout)
- [Util pack](#util-pack)
- [Patch](#patch)
- [Integration with other apps](#integration-with-other-apps)
  * [Web Service](#web-service)
  * [CLI](#cli)
  * [AI](#ai)
  * [OS](#os)
  * [Hardware](#hardware)
- [Language specific](#language-specific)
  * [Javascript/Typescript](#javascripttypescript)
  * [Python](#python)
  * [C/C++](#cc)
  * [Go](#go)
- [Configuration File](#configuration-file)
- [Documentation](#documentation)
- [Neovim Lua Library](#neovim-lua-library)
- [Neovim Lua Development](#neovim-lua-development)
- [Colorscheme](#colorscheme)
- [Neovim Distribution](#neovim-distribution)
- [GUI](#gui)
- [External Tools](#external-tools)
- [Service](#service)
- [Toy](#toy)

<!-- tocstop -->

## [Plugin Manager](./plugin-manager.md)

## [Completion](./completion.md)

## [LSP](./lsp.md)

## [Treesitter](./treesitter.md)

## [Fuzzy Finder](./fuzzy-finder.md)

## [Filer](./filer.md)

## Appearance

### [Syntax / Highlight](./syntax_highlight.md)

### [Statusline](./statusline.md)

### [Bufferline](./bufferline.md)

### Tabline

- [andrewjwaggoner/cabline.nvim](https://github.com/andrewjwaggoner/cabline.nvim) ![](https://img.shields.io/github/stars/andrewjwaggoner/cabline.nvim) ![](https://img.shields.io/github/last-commit/andrewjwaggoner/cabline.nvim) ![](https://img.shields.io/github/commit-activity/y/andrewjwaggoner/cabline.nvim)
- [rafi/tabstrip.nvim](https://github.com/rafi/tabstrip.nvim) ![](https://img.shields.io/github/stars/rafi/tabstrip.nvim) ![](https://img.shields.io/github/last-commit/rafi/tabstrip.nvim) ![](https://img.shields.io/github/commit-activity/y/rafi/tabstrip.nvim)
- [lpoto/tabline.nvim](https://github.com/lpoto/tabline.nvim) ![](https://img.shields.io/github/stars/lpoto/tabline.nvim) ![](https://img.shields.io/github/last-commit/lpoto/tabline.nvim) ![](https://img.shields.io/github/commit-activity/y/lpoto/tabline.nvim)
- [mgnsk/autotabline.nvim](https://github.com/mgnsk/autotabline.nvim) ![](https://img.shields.io/github/stars/mgnsk/autotabline.nvim) ![](https://img.shields.io/github/last-commit/mgnsk/autotabline.nvim) ![](https://img.shields.io/github/commit-activity/y/mgnsk/autotabline.nvim)
- [jryom/nvim-tabulous](https://github.com/jryom/nvim-tabulous) ![](https://img.shields.io/github/stars/jryom/nvim-tabulous) ![](https://img.shields.io/github/last-commit/jryom/nvim-tabulous) ![](https://img.shields.io/github/commit-activity/y/jryom/nvim-tabulous)
- [nathanberry97/dumbtab.nvim](https://github.com/nathanberry97/dumbtab.nvim) ![](https://img.shields.io/github/stars/nathanberry97/dumbtab.nvim) ![](https://img.shields.io/github/last-commit/nathanberry97/dumbtab.nvim) ![](https://img.shields.io/github/commit-activity/y/nathanberry97/dumbtab.nvim)
- [eliseshaffer/tableau.nvim](https://github.com/eliseshaffer/tableau.nvim) ![](https://img.shields.io/github/stars/eliseshaffer/tableau.nvim) ![](https://img.shields.io/github/last-commit/eliseshaffer/tableau.nvim) ![](https://img.shields.io/github/commit-activity/y/eliseshaffer/tableau.nvim)

### winbar

- [utilyre/barbecue.nvim](https://github.com/utilyre/barbecue.nvim) ![](https://img.shields.io/github/stars/utilyre/barbecue.nvim) ![](https://img.shields.io/github/last-commit/utilyre/barbecue.nvim) ![](https://img.shields.io/github/commit-activity/y/utilyre/barbecue.nvim)
- [aktersnurra/minibar.nvim](https://github.com/aktersnurra/minibar.nvim) ![](https://img.shields.io/github/stars/aktersnurra/minibar.nvim) ![](https://img.shields.io/github/last-commit/aktersnurra/minibar.nvim) ![](https://img.shields.io/github/commit-activity/y/aktersnurra/minibar.nvim)
- [Alighorab/winbar.nvim](https://github.com/Alighorab/winbar.nvim) ![](https://img.shields.io/github/stars/Alighorab/winbar.nvim) ![](https://img.shields.io/github/last-commit/Alighorab/winbar.nvim) ![](https://img.shields.io/github/commit-activity/y/Alighorab/winbar.nvim)
- [fgheng/winbar.nvim](https://github.com/fgheng/winbar.nvim) ![](https://img.shields.io/github/stars/fgheng/winbar.nvim) ![](https://img.shields.io/github/last-commit/fgheng/winbar.nvim) ![](https://img.shields.io/github/commit-activity/y/fgheng/winbar.nvim)

### statuscolumn

- [luukvbaal/statuscol.nvim](https://github.com/luukvbaal/statuscol.nvim) ![](https://img.shields.io/github/stars/luukvbaal/statuscol.nvim) ![](https://img.shields.io/github/last-commit/luukvbaal/statuscol.nvim) ![](https://img.shields.io/github/commit-activity/y/luukvbaal/statuscol.nvim)
- [ElPiloto/significant.nvim](https://github.com/ElPiloto/significant.nvim) ![](https://img.shields.io/github/stars/ElPiloto/significant.nvim) ![](https://img.shields.io/github/last-commit/ElPiloto/significant.nvim) ![](https://img.shields.io/github/commit-activity/y/ElPiloto/significant.nvim)

### Cursor

- [Grazfather/blinker.nvim](https://github.com/Grazfather/blinker.nvim) ![](https://img.shields.io/github/stars/Grazfather/blinker.nvim) ![](https://img.shields.io/github/last-commit/Grazfather/blinker.nvim) ![](https://img.shields.io/github/commit-activity/y/Grazfather/blinker.nvim)
- [scheisa/relpointers.nvim](https://github.com/scheisa/relpointers.nvim) ![](https://img.shields.io/github/stars/scheisa/relpointers.nvim) ![](https://img.shields.io/github/last-commit/scheisa/relpointers.nvim) ![](https://img.shields.io/github/commit-activity/y/scheisa/relpointers.nvim)
- [abcdefg233/rainbowcursor.nvim](https://github.com/abcdefg233/rainbowcursor.nvim) ![](https://img.shields.io/github/stars/abcdefg233/rainbowcursor.nvim) ![](https://img.shields.io/github/last-commit/abcdefg233/rainbowcursor.nvim) ![](https://img.shields.io/github/commit-activity/y/abcdefg233/rainbowcursor.nvim)
- [ukyouz/syntax-highlighted-cursor.nvim](https://github.com/ukyouz/syntax-highlighted-cursor.nvim) ![](https://img.shields.io/github/stars/ukyouz/syntax-highlighted-cursor.nvim) ![](https://img.shields.io/github/last-commit/ukyouz/syntax-highlighted-cursor.nvim) ![](https://img.shields.io/github/commit-activity/y/ukyouz/syntax-highlighted-cursor.nvim)

### [Cursorline / Columnline](./cursorline_columnline.md)

### Window Separators

- [nvim-zh/colorful-winsep.nvim](https://github.com/nvim-zh/colorful-winsep.nvim) ![](https://img.shields.io/github/stars/nvim-zh/colorful-winsep.nvim) ![](https://img.shields.io/github/last-commit/nvim-zh/colorful-winsep.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-zh/colorful-winsep.nvim)
- [A-Lamia/spotlight.nvim](https://github.com/A-Lamia/spotlight.nvim) ![](https://img.shields.io/github/stars/A-Lamia/spotlight.nvim) ![](https://img.shields.io/github/last-commit/A-Lamia/spotlight.nvim) ![](https://img.shields.io/github/commit-activity/y/A-Lamia/spotlight.nvim)

### Screen position

- [vvvvv/yfix.nvim](https://github.com/vvvvv/yfix.nvim) ![](https://img.shields.io/github/stars/vvvvv/yfix.nvim) ![](https://img.shields.io/github/last-commit/vvvvv/yfix.nvim) ![](https://img.shields.io/github/commit-activity/y/vvvvv/yfix.nvim)
- [Aasim-A/scrollEOF.nvim](https://github.com/Aasim-A/scrollEOF.nvim) ![](https://img.shields.io/github/stars/Aasim-A/scrollEOF.nvim) ![](https://img.shields.io/github/last-commit/Aasim-A/scrollEOF.nvim) ![](https://img.shields.io/github/commit-activity/y/Aasim-A/scrollEOF.nvim)
- [gcanoxl/better-zz.nvim](https://github.com/gcanoxl/better-zz.nvim) ![](https://img.shields.io/github/stars/gcanoxl/better-zz.nvim) ![](https://img.shields.io/github/last-commit/gcanoxl/better-zz.nvim) ![](https://img.shields.io/github/commit-activity/y/gcanoxl/better-zz.nvim)
- [MagnetizedFreckles/centerscroll.nvim](https://github.com/MagnetizedFreckles/centerscroll.nvim) ![](https://img.shields.io/github/stars/MagnetizedFreckles/centerscroll.nvim) ![](https://img.shields.io/github/last-commit/MagnetizedFreckles/centerscroll.nvim) ![](https://img.shields.io/github/commit-activity/y/MagnetizedFreckles/centerscroll.nvim)

### Wrap line

- [andrewferrier/wrapping.nvim](https://github.com/andrewferrier/wrapping.nvim) ![](https://img.shields.io/github/stars/andrewferrier/wrapping.nvim) ![](https://img.shields.io/github/last-commit/andrewferrier/wrapping.nvim) ![](https://img.shields.io/github/commit-activity/y/andrewferrier/wrapping.nvim)
- [benlubas/wrapping-paper.nvim](https://github.com/benlubas/wrapping-paper.nvim) ![](https://img.shields.io/github/stars/benlubas/wrapping-paper.nvim) ![](https://img.shields.io/github/last-commit/benlubas/wrapping-paper.nvim) ![](https://img.shields.io/github/commit-activity/y/benlubas/wrapping-paper.nvim)

### [Mode](./mode.md)

### Scrollbar

- [petertriho/nvim-scrollbar](https://github.com/petertriho/nvim-scrollbar) ![](https://img.shields.io/github/stars/petertriho/nvim-scrollbar) ![](https://img.shields.io/github/last-commit/petertriho/nvim-scrollbar) ![](https://img.shields.io/github/commit-activity/y/petertriho/nvim-scrollbar)
- [lewis6991/satellite.nvim](https://github.com/lewis6991/satellite.nvim) ![](https://img.shields.io/github/stars/lewis6991/satellite.nvim) ![](https://img.shields.io/github/last-commit/lewis6991/satellite.nvim) ![](https://img.shields.io/github/commit-activity/y/lewis6991/satellite.nvim)
- [dstein64/nvim-scrollview](https://github.com/dstein64/nvim-scrollview) ![](https://img.shields.io/github/stars/dstein64/nvim-scrollview) ![](https://img.shields.io/github/last-commit/dstein64/nvim-scrollview) ![](https://img.shields.io/github/commit-activity/y/dstein64/nvim-scrollview)
- [Xuyuanp/scrollbar.nvim](https://github.com/Xuyuanp/scrollbar.nvim) ![](https://img.shields.io/github/stars/Xuyuanp/scrollbar.nvim) ![](https://img.shields.io/github/last-commit/Xuyuanp/scrollbar.nvim) ![](https://img.shields.io/github/commit-activity/y/Xuyuanp/scrollbar.nvim)
- [dsummersl/nvim-sluice](https://github.com/dsummersl/nvim-sluice) ![](https://img.shields.io/github/stars/dsummersl/nvim-sluice) ![](https://img.shields.io/github/last-commit/dsummersl/nvim-sluice) ![](https://img.shields.io/github/commit-activity/y/dsummersl/nvim-sluice)
- [kensyo/nvim-scrlbkun](https://github.com/kensyo/nvim-scrlbkun) ![](https://img.shields.io/github/stars/kensyo/nvim-scrlbkun) ![](https://img.shields.io/github/last-commit/kensyo/nvim-scrlbkun) ![](https://img.shields.io/github/commit-activity/y/kensyo/nvim-scrlbkun)
- [doums/dmap.nvim](https://github.com/doums/dmap.nvim) ![](https://img.shields.io/github/stars/doums/dmap.nvim) ![](https://img.shields.io/github/last-commit/doums/dmap.nvim) ![](https://img.shields.io/github/commit-activity/y/doums/dmap.nvim)

### Sidebar

- [GustavoKatel/sidebar.nvim](https://github.com/GustavoKatel/sidebar.nvim) ![](https://img.shields.io/github/stars/GustavoKatel/sidebar.nvim) ![](https://img.shields.io/github/last-commit/GustavoKatel/sidebar.nvim) ![](https://img.shields.io/github/commit-activity/y/GustavoKatel/sidebar.nvim)
- [ldelossa/litee.nvim](https://github.com/ldelossa/litee.nvim) ![](https://img.shields.io/github/stars/ldelossa/litee.nvim) ![](https://img.shields.io/github/last-commit/ldelossa/litee.nvim) ![](https://img.shields.io/github/commit-activity/y/ldelossa/litee.nvim)
- [arakkkkk/switchpanel.nvim](https://github.com/arakkkkk/switchpanel.nvim) ![](https://img.shields.io/github/stars/arakkkkk/switchpanel.nvim) ![](https://img.shields.io/github/last-commit/arakkkkk/switchpanel.nvim) ![](https://img.shields.io/github/commit-activity/y/arakkkkk/switchpanel.nvim)

### Menu

- [sunjon/stylish.nvim](https://github.com/sunjon/stylish.nvim) ![](https://img.shields.io/github/stars/sunjon/stylish.nvim) ![](https://img.shields.io/github/last-commit/sunjon/stylish.nvim) ![](https://img.shields.io/github/commit-activity/y/sunjon/stylish.nvim)
- [notomo/piemenu.nvim](https://github.com/notomo/piemenu.nvim) ![](https://img.shields.io/github/stars/notomo/piemenu.nvim) ![](https://img.shields.io/github/last-commit/notomo/piemenu.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/piemenu.nvim)
- [meznaric/conmenu](https://github.com/meznaric/conmenu) ![](https://img.shields.io/github/stars/meznaric/conmenu) ![](https://img.shields.io/github/last-commit/meznaric/conmenu) ![](https://img.shields.io/github/commit-activity/y/meznaric/conmenu)
- [willothy/hollywood.nvim](https://github.com/willothy/hollywood.nvim) ![](https://img.shields.io/github/stars/willothy/hollywood.nvim) ![](https://img.shields.io/github/last-commit/willothy/hollywood.nvim) ![](https://img.shields.io/github/commit-activity/y/willothy/hollywood.nvim)

### Minimap

- [gorbit99/codewindow.nvim](https://github.com/gorbit99/codewindow.nvim) ![](https://img.shields.io/github/stars/gorbit99/codewindow.nvim) ![](https://img.shields.io/github/last-commit/gorbit99/codewindow.nvim) ![](https://img.shields.io/github/commit-activity/y/gorbit99/codewindow.nvim)
- [ziontee113/neo-minimap](https://github.com/ziontee113/neo-minimap) ![](https://img.shields.io/github/stars/ziontee113/neo-minimap) ![](https://img.shields.io/github/last-commit/ziontee113/neo-minimap) ![](https://img.shields.io/github/commit-activity/y/ziontee113/neo-minimap)
- [echasnovski/mini.map](https://github.com/echasnovski/mini.map) ![](https://img.shields.io/github/stars/echasnovski/mini.map) ![](https://img.shields.io/github/last-commit/echasnovski/mini.map) ![](https://img.shields.io/github/commit-activity/y/echasnovski/mini.map)

### Highlight current function

- [folke/twilight.nvim](https://github.com/folke/twilight.nvim) ![](https://img.shields.io/github/stars/folke/twilight.nvim) ![](https://img.shields.io/github/last-commit/folke/twilight.nvim) ![](https://img.shields.io/github/commit-activity/y/folke/twilight.nvim)
- [koenverburg/peepsight.nvim](https://github.com/koenverburg/peepsight.nvim) ![](https://img.shields.io/github/stars/koenverburg/peepsight.nvim) ![](https://img.shields.io/github/last-commit/koenverburg/peepsight.nvim) ![](https://img.shields.io/github/commit-activity/y/koenverburg/peepsight.nvim)

### listchars

- [fraso-dev/nvim-listchars](https://github.com/fraso-dev/nvim-listchars) ![](https://img.shields.io/github/stars/fraso-dev/nvim-listchars) ![](https://img.shields.io/github/last-commit/fraso-dev/nvim-listchars) ![](https://img.shields.io/github/commit-activity/y/fraso-dev/nvim-listchars)
- [mcauley-penney/visual-whitespace.nvim](https://github.com/mcauley-penney/visual-whitespace.nvim) ![](https://img.shields.io/github/stars/mcauley-penney/visual-whitespace.nvim) ![](https://img.shields.io/github/last-commit/mcauley-penney/visual-whitespace.nvim) ![](https://img.shields.io/github/commit-activity/y/mcauley-penney/visual-whitespace.nvim)

### Background

- [xiyaowong/transparent.nvim](https://github.com/xiyaowong/transparent.nvim) ![](https://img.shields.io/github/stars/xiyaowong/transparent.nvim) ![](https://img.shields.io/github/last-commit/xiyaowong/transparent.nvim) ![](https://img.shields.io/github/commit-activity/y/xiyaowong/transparent.nvim)
- [typicode/bg.nvim](https://github.com/typicode/bg.nvim) ![](https://img.shields.io/github/stars/typicode/bg.nvim) ![](https://img.shields.io/github/last-commit/typicode/bg.nvim) ![](https://img.shields.io/github/commit-activity/y/typicode/bg.nvim)
- [orumin/ya-seiya.nvim](https://github.com/orumin/ya-seiya.nvim) ![](https://img.shields.io/github/stars/orumin/ya-seiya.nvim) ![](https://img.shields.io/github/last-commit/orumin/ya-seiya.nvim) ![](https://img.shields.io/github/commit-activity/y/orumin/ya-seiya.nvim)
- [wangl-cc/auto-bg.nvim](https://github.com/wangl-cc/auto-bg.nvim) ![](https://img.shields.io/github/stars/wangl-cc/auto-bg.nvim) ![](https://img.shields.io/github/last-commit/wangl-cc/auto-bg.nvim) ![](https://img.shields.io/github/commit-activity/y/wangl-cc/auto-bg.nvim)

## [Buffer, Window, Tab Management](./buffer_window_tab-management.md)

## [Terminal](./terminal.md)

## [Motion](./motion.md)

## [Jump](./jump.md)

## Editing support

### Select Edit

- [00sapo/visual.nvim](https://github.com/00sapo/visual.nvim) ![](https://img.shields.io/github/stars/00sapo/visual.nvim) ![](https://img.shields.io/github/last-commit/00sapo/visual.nvim) ![](https://img.shields.io/github/commit-activity/y/00sapo/visual.nvim)

### Insert

- [njaczko/nvim-dummy-text](https://github.com/njaczko/nvim-dummy-text) ![](https://img.shields.io/github/stars/njaczko/nvim-dummy-text) ![](https://img.shields.io/github/last-commit/njaczko/nvim-dummy-text) ![](https://img.shields.io/github/commit-activity/y/njaczko/nvim-dummy-text)
- [bwintertkb/enclose_nav.nvim](https://github.com/bwintertkb/enclose_nav.nvim) ![](https://img.shields.io/github/stars/bwintertkb/enclose_nav.nvim) ![](https://img.shields.io/github/last-commit/bwintertkb/enclose_nav.nvim) ![](https://img.shields.io/github/commit-activity/y/bwintertkb/enclose_nav.nvim)
- [AntonVanAssche/date-time-inserter.nvim](https://github.com/AntonVanAssche/date-time-inserter.nvim) ![](https://img.shields.io/github/stars/AntonVanAssche/date-time-inserter.nvim) ![](https://img.shields.io/github/last-commit/AntonVanAssche/date-time-inserter.nvim) ![](https://img.shields.io/github/commit-activity/y/AntonVanAssche/date-time-inserter.nvim)
- [resonyze/erase_node.nvim](https://github.com/resonyze/erase_node.nvim) ![](https://img.shields.io/github/stars/resonyze/erase_node.nvim) ![](https://img.shields.io/github/last-commit/resonyze/erase_node.nvim) ![](https://img.shields.io/github/commit-activity/y/resonyze/erase_node.nvim)
- [adammccartney/nvim-rinse](https://github.com/adammccartney/nvim-rinse) ![](https://img.shields.io/github/stars/adammccartney/nvim-rinse) ![](https://img.shields.io/github/last-commit/adammccartney/nvim-rinse) ![](https://img.shields.io/github/commit-activity/y/adammccartney/nvim-rinse)
- [AgusDOLARD/backout.nvim](https://github.com/AgusDOLARD/backout.nvim) ![](https://img.shields.io/github/stars/AgusDOLARD/backout.nvim) ![](https://img.shields.io/github/last-commit/AgusDOLARD/backout.nvim) ![](https://img.shields.io/github/commit-activity/y/AgusDOLARD/backout.nvim)
- [Someone-s-out-there/stutter.nvim](https://github.com/Someone-s-out-there/stutter.nvim) ![](https://img.shields.io/github/stars/Someone-s-out-there/stutter.nvim) ![](https://img.shields.io/github/last-commit/Someone-s-out-there/stutter.nvim) ![](https://img.shields.io/github/commit-activity/y/Someone-s-out-there/stutter.nvim)
- [nobody-famous/lima.nvim](https://github.com/nobody-famous/lima.nvim) ![](https://img.shields.io/github/stars/nobody-famous/lima.nvim) ![](https://img.shields.io/github/last-commit/nobody-famous/lima.nvim) ![](https://img.shields.io/github/commit-activity/y/nobody-famous/lima.nvim)

#### Smart Tab

- [boltlessengineer/smart-tab.nvim](https://github.com/boltlessengineer/smart-tab.nvim) ![](https://img.shields.io/github/stars/boltlessengineer/smart-tab.nvim) ![](https://img.shields.io/github/last-commit/boltlessengineer/smart-tab.nvim) ![](https://img.shields.io/github/commit-activity/y/boltlessengineer/smart-tab.nvim)
- [nvim-jo/smarttab.nvim](https://github.com/nvim-jo/smarttab.nvim) ![](https://img.shields.io/github/stars/nvim-jo/smarttab.nvim) ![](https://img.shields.io/github/last-commit/nvim-jo/smarttab.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-jo/smarttab.nvim)
- [lsvmello/elastictabstops.nvim](https://github.com/lsvmello/elastictabstops.nvim) ![](https://img.shields.io/github/stars/lsvmello/elastictabstops.nvim) ![](https://img.shields.io/github/last-commit/lsvmello/elastictabstops.nvim) ![](https://img.shields.io/github/commit-activity/y/lsvmello/elastictabstops.nvim)

### [Auto Insert](./auto-insert.md)

### matchparen

- [monkoose/matchparen.nvim](https://github.com/monkoose/matchparen.nvim) ![](https://img.shields.io/github/stars/monkoose/matchparen.nvim) ![](https://img.shields.io/github/last-commit/monkoose/matchparen.nvim) ![](https://img.shields.io/github/commit-activity/y/monkoose/matchparen.nvim)
- [rareitems/hl_match_area.nvim](https://github.com/rareitems/hl_match_area.nvim) ![](https://img.shields.io/github/stars/rareitems/hl_match_area.nvim) ![](https://img.shields.io/github/last-commit/rareitems/hl_match_area.nvim) ![](https://img.shields.io/github/commit-activity/y/rareitems/hl_match_area.nvim)
- [utilyre/sentiment.nvim](https://github.com/utilyre/sentiment.nvim) ![](https://img.shields.io/github/stars/utilyre/sentiment.nvim) ![](https://img.shields.io/github/last-commit/utilyre/sentiment.nvim) ![](https://img.shields.io/github/commit-activity/y/utilyre/sentiment.nvim)

### [Convert](./convert.md)

### [Indent](./indent.md)

### Align

- [Vonr/align.nvim](https://github.com/Vonr/align.nvim) ![](https://img.shields.io/github/stars/Vonr/align.nvim) ![](https://img.shields.io/github/last-commit/Vonr/align.nvim) ![](https://img.shields.io/github/commit-activity/y/Vonr/align.nvim)
- [RRethy/nvim-align](https://github.com/RRethy/nvim-align) ![](https://img.shields.io/github/stars/RRethy/nvim-align) ![](https://img.shields.io/github/last-commit/RRethy/nvim-align) ![](https://img.shields.io/github/commit-activity/y/RRethy/nvim-align)
- [echasnovski/mini.align](https://github.com/echasnovski/mini.align) ![](https://img.shields.io/github/stars/echasnovski/mini.align) ![](https://img.shields.io/github/last-commit/echasnovski/mini.align) ![](https://img.shields.io/github/commit-activity/y/echasnovski/mini.align)
- [vzze/aligner.nvim](https://github.com/vzze/aligner.nvim) ![](https://img.shields.io/github/stars/vzze/aligner.nvim) ![](https://img.shields.io/github/last-commit/vzze/aligner.nvim) ![](https://img.shields.io/github/commit-activity/y/vzze/aligner.nvim)
- [jakeru/columnize.nvim](https://github.com/jakeru/columnize.nvim) ![](https://img.shields.io/github/stars/jakeru/columnize.nvim) ![](https://img.shields.io/github/last-commit/jakeru/columnize.nvim) ![](https://img.shields.io/github/commit-activity/y/jakeru/columnize.nvim)
- [chuck-flowers/align-selection.nvim](https://github.com/chuck-flowers/align-selection.nvim) ![](https://img.shields.io/github/stars/chuck-flowers/align-selection.nvim) ![](https://img.shields.io/github/last-commit/chuck-flowers/align-selection.nvim) ![](https://img.shields.io/github/commit-activity/y/chuck-flowers/align-selection.nvim)

### [TextObject, Operator](./textobject_operator.md)

### Parenthetical edit

- [julienvincent/nvim-paredit](https://github.com/julienvincent/nvim-paredit) ![](https://img.shields.io/github/stars/julienvincent/nvim-paredit) ![](https://img.shields.io/github/last-commit/julienvincent/nvim-paredit) ![](https://img.shields.io/github/commit-activity/y/julienvincent/nvim-paredit)
  - [julienvincent/nvim-paredit-fennel](https://github.com/julienvincent/nvim-paredit-fennel) ![](https://img.shields.io/github/stars/julienvincent/nvim-paredit-fennel) ![](https://img.shields.io/github/last-commit/julienvincent/nvim-paredit-fennel) ![](https://img.shields.io/github/commit-activity/y/julienvincent/nvim-paredit-fennel)
  - [dnebauer/dn-markdown.nvim](https://github.com/dnebauer/dn-markdown.nvim) ![](https://img.shields.io/github/stars/dnebauer/dn-markdown.nvim) ![](https://img.shields.io/github/last-commit/dnebauer/dn-markdown.nvim) ![](https://img.shields.io/github/commit-activity/y/dnebauer/dn-markdown.nvim)

### Large file

- [LunarVim/bigfile.nvim](https://github.com/LunarVim/bigfile.nvim) ![](https://img.shields.io/github/stars/LunarVim/bigfile.nvim) ![](https://img.shields.io/github/last-commit/LunarVim/bigfile.nvim) ![](https://img.shields.io/github/commit-activity/y/LunarVim/bigfile.nvim)
- [pteroctopus/faster.nvim](https://github.com/pteroctopus/faster.nvim) ![](https://img.shields.io/github/stars/pteroctopus/faster.nvim) ![](https://img.shields.io/github/last-commit/pteroctopus/faster.nvim) ![](https://img.shields.io/github/commit-activity/y/pteroctopus/faster.nvim)

### Misc

- [abecodes/tabout.nvim](https://github.com/abecodes/tabout.nvim) ![](https://img.shields.io/github/stars/abecodes/tabout.nvim) ![](https://img.shields.io/github/last-commit/abecodes/tabout.nvim) ![](https://img.shields.io/github/commit-activity/y/abecodes/tabout.nvim)
- [Allendang/nvim-expand-expr](https://github.com/AllenDang/nvim-expand-expr) ![](https://img.shields.io/github/stars/Allendang/nvim-expand-expr) ![](https://img.shields.io/github/last-commit/Allendang/nvim-expand-expr) ![](https://img.shields.io/github/commit-activity/y/Allendang/nvim-expand-expr)
- [saifulapm/chartoggle.nvim](https://github.com/saifulapm/chartoggle.nvim) ![](https://img.shields.io/github/stars/saifulapm/chartoggle.nvim) ![](https://img.shields.io/github/last-commit/saifulapm/chartoggle.nvim) ![](https://img.shields.io/github/commit-activity/y/saifulapm/chartoggle.nvim)

## Other Standard Feature Enhancement

### [Search, Replace, Select](./search_replace_grep_select.md)

### [Mapping](./mapping.md)

### [Yank, Paste](./yank_paste.md)

### Split / Join

- [AckslD/nvim-trevJ.lua](https://github.com/AckslD/nvim-trevJ.lua) ![](https://img.shields.io/github/stars/AckslD/nvim-trevJ.lua) ![](https://img.shields.io/github/last-commit/AckslD/nvim-trevJ.lua) ![](https://img.shields.io/github/commit-activity/y/AckslD/nvim-trevJ.lua)
- [kizza/joinery.nvim](https://github.com/kizza/joinery.nvim) ![](https://img.shields.io/github/stars/kizza/joinery.nvim) ![](https://img.shields.io/github/last-commit/kizza/joinery.nvim) ![](https://img.shields.io/github/commit-activity/y/kizza/joinery.nvim)
- [uga-rosa/join.nvim](https://github.com/uga-rosa/join.nvim) ![](https://img.shields.io/github/stars/uga-rosa/join.nvim) ![](https://img.shields.io/github/last-commit/uga-rosa/join.nvim) ![](https://img.shields.io/github/commit-activity/y/uga-rosa/join.nvim)
- [aarondiel/spread.nvim](https://github.com/aarondiel/spread.nvim) ![](https://img.shields.io/github/stars/aarondiel/spread.nvim) ![](https://img.shields.io/github/last-commit/aarondiel/spread.nvim) ![](https://img.shields.io/github/commit-activity/y/aarondiel/spread.nvim)
- [Wansmer/treesj](https://github.com/Wansmer/treesj) ![](https://img.shields.io/github/stars/Wansmer/treesj) ![](https://img.shields.io/github/last-commit/Wansmer/treesj) ![](https://img.shields.io/github/commit-activity/y/Wansmer/treesj)
- [bennypowers/splitjoin.nvim](https://github.com/bennypowers/splitjoin.nvim) ![](https://img.shields.io/github/stars/bennypowers/splitjoin.nvim) ![](https://img.shields.io/github/last-commit/bennypowers/splitjoin.nvim) ![](https://img.shields.io/github/commit-activity/y/bennypowers/splitjoin.nvim)
- [echasnovski/mini.splitjoin](https://github.com/echasnovski/mini.splitjoin) ![](https://img.shields.io/github/stars/echasnovski/mini.splitjoin) ![](https://img.shields.io/github/last-commit/echasnovski/mini.splitjoin) ![](https://img.shields.io/github/commit-activity/y/echasnovski/mini.splitjoin)
- [tanloong/interlaced.nvim](https://github.com/tanloong/interlaced.nvim) ![](https://img.shields.io/github/stars/tanloong/interlaced.nvim) ![](https://img.shields.io/github/last-commit/tanloong/interlaced.nvim) ![](https://img.shields.io/github/commit-activity/y/tanloong/interlaced.nvim)

### Number

- [nkakouros-original/numbers.nvim](https://github.com/nkakouros-original/numbers.nvim) ![](https://img.shields.io/github/stars/nkakouros-original/numbers.nvim) ![](https://img.shields.io/github/last-commit/nkakouros-original/numbers.nvim) ![](https://img.shields.io/github/commit-activity/y/nkakouros-original/numbers.nvim)
- [sitiom/nvim-numbertoggle](https://github.com/sitiom/nvim-numbertoggle) ![](https://img.shields.io/github/stars/sitiom/nvim-numbertoggle) ![](https://img.shields.io/github/last-commit/sitiom/nvim-numbertoggle) ![](https://img.shields.io/github/commit-activity/y/sitiom/nvim-numbertoggle)
- [joshdirkx/toggle-relativenumber.nvim](https://github.com/joshdirkx/toggle-relativenumber.nvim) ![](https://img.shields.io/github/stars/joshdirkx/toggle-relativenumber.nvim) ![](https://img.shields.io/github/last-commit/joshdirkx/toggle-relativenumber.nvim) ![](https://img.shields.io/github/commit-activity/y/joshdirkx/toggle-relativenumber.nvim)
- [cpea2506/relative-toggle.nvim](https://github.com/cpea2506/relative-toggle.nvim) ![](https://img.shields.io/github/stars/cpea2506/relative-toggle.nvim) ![](https://img.shields.io/github/last-commit/cpea2506/relative-toggle.nvim) ![](https://img.shields.io/github/commit-activity/y/cpea2506/relative-toggle.nvim)
- [gvlatko/inline-relative-numbers.nvim](https://github.com/gvlatko/inline-relative-numbers.nvim) ![](https://img.shields.io/github/stars/gvlatko/inline-relative-numbers.nvim) ![](https://img.shields.io/github/last-commit/gvlatko/inline-relative-numbers.nvim) ![](https://img.shields.io/github/commit-activity/y/gvlatko/inline-relative-numbers.nvim)
- [togawalk/relative-toggle.nvim](https://github.com/togawalk/relative-toggle.nvim) ![](https://img.shields.io/github/stars/togawalk/relative-toggle.nvim) ![](https://img.shields.io/github/last-commit/togawalk/relative-toggle.nvim) ![](https://img.shields.io/github/commit-activity/y/togawalk/relative-toggle.nvim)

### [Mark](./mark.md)

### Undo

- [haolian9/redostr.nvim](https://github.com/haolian9/redostr.nvim) ![](https://img.shields.io/github/stars/haolian9/redostr.nvim) ![](https://img.shields.io/github/last-commit/haolian9/redostr.nvim) ![](https://img.shields.io/github/commit-activity/y/haolian9/redostr.nvim)
- [debugloop/telescope-undo.nvim](https://github.com/debugloop/telescope-undo.nvim) ![](https://img.shields.io/github/stars/debugloop/telescope-undo.nvim) ![](https://img.shields.io/github/last-commit/debugloop/telescope-undo.nvim) ![](https://img.shields.io/github/commit-activity/y/debugloop/telescope-undo.nvim)
- [tzachar/highlight-undo.nvim](https://github.com/tzachar/highlight-undo.nvim) ![](https://img.shields.io/github/stars/tzachar/highlight-undo.nvim) ![](https://img.shields.io/github/last-commit/tzachar/highlight-undo.nvim) ![](https://img.shields.io/github/commit-activity/y/tzachar/highlight-undo.nvim)

### Diff

- [aaron-p1/compare-remotes.nvim](https://github.com/aaron-p1/compare-remotes.nvim) ![](https://img.shields.io/github/stars/aaron-p1/compare-remotes.nvim) ![](https://img.shields.io/github/last-commit/aaron-p1/compare-remotes.nvim) ![](https://img.shields.io/github/commit-activity/y/aaron-p1/compare-remotes.nvim)
- [jemag/telescope-diff.nvim](https://github.com/jemag/telescope-diff.nvim) ![](https://img.shields.io/github/stars/jemag/telescope-diff.nvim) ![](https://img.shields.io/github/last-commit/jemag/telescope-diff.nvim) ![](https://img.shields.io/github/commit-activity/y/jemag/telescope-diff.nvim)
- [ryutaro-asada/partial-diff.nvim](https://github.com/ryutaro-asada/partial-diff.nvim) ![](https://img.shields.io/github/stars/ryutaro-asada/partial-diff.nvim) ![](https://img.shields.io/github/last-commit/ryutaro-asada/partial-diff.nvim) ![](https://img.shields.io/github/commit-activity/y/ryutaro-asada/partial-diff.nvim)

#### Register

- [antosha417/nvim-compare-with-clipboard](https://github.com/antosha417/nvim-compare-with-clipboard) ![](https://img.shields.io/github/stars/antosha417/nvim-compare-with-clipboard) ![](https://img.shields.io/github/last-commit/antosha417/nvim-compare-with-clipboard) ![](https://img.shields.io/github/commit-activity/y/antosha417/nvim-compare-with-clipboard)
- [ksuimraoShare/diff-register.nvim](https://github.com/ksuimraoShare/diff-register.nvim) ![](https://img.shields.io/github/stars/ksuimraoShare/diff-register.nvim) ![](https://img.shields.io/github/last-commit/ksuimraoShare/diff-register.nvim) ![](https://img.shields.io/github/commit-activity/y/ksuimraoShare/diff-register.nvim)

### Tags

- [nanotee/nvim-lsp-basics](https://github.com/nanotee/nvim-lsp-basics) ![](https://img.shields.io/github/stars/nanotee/nvim-lsp-basics) ![](https://img.shields.io/github/last-commit/nanotee/nvim-lsp-basics) ![](https://img.shields.io/github/commit-activity/y/nanotee/nvim-lsp-basics)
- [weilbith/nvim-floating-tag-preview](https://github.com/weilbith/nvim-floating-tag-preview) ![](https://img.shields.io/github/stars/weilbith/nvim-floating-tag-preview) ![](https://img.shields.io/github/last-commit/weilbith/nvim-floating-tag-preview) ![](https://img.shields.io/github/commit-activity/y/weilbith/nvim-floating-tag-preview)
- [quangnguyen30192/cmp-nvim-tags](https://github.com/quangnguyen30192/cmp-nvim-tags) ![](https://img.shields.io/github/stars/quangnguyen30192/cmp-nvim-tags) ![](https://img.shields.io/github/last-commit/quangnguyen30192/cmp-nvim-tags) ![](https://img.shields.io/github/commit-activity/y/quangnguyen30192/cmp-nvim-tags)
- [linrongbin16/gentags.nvim](https://github.com/linrongbin16/gentags.nvim) ![](https://img.shields.io/github/stars/linrongbin16/gentags.nvim) ![](https://img.shields.io/github/last-commit/linrongbin16/gentags.nvim) ![](https://img.shields.io/github/commit-activity/y/linrongbin16/gentags.nvim)

### [Fold / Conceal](./fold.md)

### Calculation

- [hrsh7th/cmp-calc](https://github.com/hrsh7th/cmp-calc) ![](https://img.shields.io/github/stars/hrsh7th/cmp-calc) ![](https://img.shields.io/github/last-commit/hrsh7th/cmp-calc) ![](https://img.shields.io/github/commit-activity/y/hrsh7th/cmp-calc)
- [jbyuki/quickmath.nvim](https://github.com/jbyuki/quickmath.nvim) ![](https://img.shields.io/github/stars/jbyuki/quickmath.nvim) ![](https://img.shields.io/github/last-commit/jbyuki/quickmath.nvim) ![](https://img.shields.io/github/commit-activity/y/jbyuki/quickmath.nvim)
- [vzze/calculator.nvim](https://github.com/vzze/calculator.nvim) ![](https://img.shields.io/github/stars/vzze/calculator.nvim) ![](https://img.shields.io/github/last-commit/vzze/calculator.nvim) ![](https://img.shields.io/github/commit-activity/y/vzze/calculator.nvim)
- [rapan931/dentaku.nvim](https://github.com/rapan931/dentaku.nvim) ![](https://img.shields.io/github/stars/rapan931/dentaku.nvim) ![](https://img.shields.io/github/last-commit/rapan931/dentaku.nvim) ![](https://img.shields.io/github/commit-activity/y/rapan931/dentaku.nvim)
- [trmckay/based.nvim](https://github.com/trmckay/based.nvim) ![](https://img.shields.io/github/stars/trmckay/based.nvim) ![](https://img.shields.io/github/last-commit/trmckay/based.nvim) ![](https://img.shields.io/github/commit-activity/y/trmckay/based.nvim)
- [Apeiros-46B/qalc.nvim](https://github.com/Apeiros-46B/qalc.nvim) ![](https://img.shields.io/github/stars/Apeiros-46B/qalc.nvim) ![](https://img.shields.io/github/last-commit/Apeiros-46B/qalc.nvim) ![](https://img.shields.io/github/commit-activity/y/Apeiros-46B/qalc.nvim)
- [penryu/rp.nvim](https://github.com/penryu/rp.nvim) ![](https://img.shields.io/github/stars/penryu/rp.nvim) ![](https://img.shields.io/github/last-commit/penryu/rp.nvim) ![](https://img.shields.io/github/commit-activity/y/penryu/rp.nvim)

### [Command](./command.md)

### [Command Line](./commandline.md)

### [Spell check](./spellcheck.md)

### Dictionary

- [uga-rosa/cmp-dictionary](https://github.com/uga-rosa/cmp-dictionary) ![](https://img.shields.io/github/stars/uga-rosa/cmp-dictionary) ![](https://img.shields.io/github/last-commit/uga-rosa/cmp-dictionary) ![](https://img.shields.io/github/commit-activity/y/uga-rosa/cmp-dictionary)
- [PaysanCorrezien/dictionary.nvim](https://github.com/PaysanCorrezien/dictionary.nvim) ![](https://img.shields.io/github/stars/PaysanCorrezien/dictionary.nvim) ![](https://img.shields.io/github/last-commit/PaysanCorrezien/dictionary.nvim) ![](https://img.shields.io/github/commit-activity/y/PaysanCorrezien/dictionary.nvim)
- [Nealium/dict-popup.nvim](https://github.com/Nealium/dict-popup.nvim) ![](https://img.shields.io/github/stars/Nealium/dict-popup.nvim) ![](https://img.shields.io/github/last-commit/Nealium/dict-popup.nvim) ![](https://img.shields.io/github/commit-activity/y/Nealium/dict-popup.nvim)

### digraph

- [jonathanforhan/nvim-glyph](https://github.com/jonathanforhan/nvim-glyph) ![](https://img.shields.io/github/stars/jonathanforhan/nvim-glyph) ![](https://img.shields.io/github/last-commit/jonathanforhan/nvim-glyph) ![](https://img.shields.io/github/commit-activity/y/jonathanforhan/nvim-glyph)
- [adorostkar/NGG.nvim](https://github.com/adorostkar/NGG.nvim) ![](https://img.shields.io/github/stars/adorostkar/NGG.nvim) ![](https://img.shields.io/github/last-commit/adorostkar/NGG.nvim) ![](https://img.shields.io/github/commit-activity/y/adorostkar/NGG.nvim)

### Abbreviation

- [0styx0/abbreinder.nvim](https://github.com/0styx0/abbreinder.nvim) ![](https://img.shields.io/github/stars/0styx0/abbreinder.nvim) ![](https://img.shields.io/github/last-commit/0styx0/abbreinder.nvim) ![](https://img.shields.io/github/commit-activity/y/0styx0/abbreinder.nvim)
- [Mateiadrielrafael/scrap.nvim](https://github.com/Mateiadrielrafael/scrap.nvim) ![](https://img.shields.io/github/stars/Mateiadrielrafael/scrap.nvim) ![](https://img.shields.io/github/last-commit/Mateiadrielrafael/scrap.nvim) ![](https://img.shields.io/github/commit-activity/y/Mateiadrielrafael/scrap.nvim)
- [shadyalfred/electric-quotes.nvim](https://github.com/shadyalfred/electric-quotes.nvim) ![](https://img.shields.io/github/stars/shadyalfred/electric-quotes.nvim) ![](https://img.shields.io/github/last-commit/shadyalfred/electric-quotes.nvim) ![](https://img.shields.io/github/commit-activity/y/shadyalfred/electric-quotes.nvim)

### [Quickfix / Location](./quickfix_location.md)

### cd(change directory)

- [nvim-telescope/telescope-z.nvim](https://github.com/nvim-telescope/telescope-z.nvim) ![](https://img.shields.io/github/stars/nvim-telescope/telescope-z.nvim) ![](https://img.shields.io/github/last-commit/nvim-telescope/telescope-z.nvim) ![](https://img.shields.io/github/commit-activity/y/nvim-telescope/telescope-z.nvim)
- [jvgrootveld/telescope-zoxide](https://github.com/jvgrootveld/telescope-zoxide) ![](https://img.shields.io/github/stars/jvgrootveld/telescope-zoxide) ![](https://img.shields.io/github/last-commit/jvgrootveld/telescope-zoxide) ![](https://img.shields.io/github/commit-activity/y/jvgrootveld/telescope-zoxide)
- [Zane-/cder.nvim](https://github.com/Zane-/cder.nvim) ![](https://img.shields.io/github/stars/Zane-/cder.nvim) ![](https://img.shields.io/github/last-commit/Zane-/cder.nvim) ![](https://img.shields.io/github/commit-activity/y/Zane-/cder.nvim)
- [9999years/broot.nvim](https://github.com/9999years/broot.nvim) ![](https://img.shields.io/github/stars/9999years/broot.nvim) ![](https://img.shields.io/github/last-commit/9999years/broot.nvim) ![](https://img.shields.io/github/commit-activity/y/9999years/broot.nvim)
- [lexay/telescope-zoxide.nvim](https://github.com/lexay/telescope-zoxide.nvim) ![](https://img.shields.io/github/stars/lexay/telescope-zoxide.nvim) ![](https://img.shields.io/github/last-commit/lexay/telescope-zoxide.nvim) ![](https://img.shields.io/github/commit-activity/y/lexay/telescope-zoxide.nvim)
- [phanen/dirstack.nvim](https://github.com/phanen/dirstack.nvim) ![](https://img.shields.io/github/stars/phanen/dirstack.nvim) ![](https://img.shields.io/github/last-commit/phanen/dirstack.nvim) ![](https://img.shields.io/github/commit-activity/y/phanen/dirstack.nvim)
- [itsfrank/cd-stack.nvim](https://github.com/itsfrank/cd-stack.nvim) ![](https://img.shields.io/github/stars/itsfrank/cd-stack.nvim) ![](https://img.shields.io/github/last-commit/itsfrank/cd-stack.nvim) ![](https://img.shields.io/github/commit-activity/y/itsfrank/cd-stack.nvim)

#### z

- [skywind3000/z.lua](https://github.com/skywind3000/z.lua) ![](https://img.shields.io/github/stars/skywind3000/z.lua) ![](https://img.shields.io/github/last-commit/skywind3000/z.lua) ![](https://img.shields.io/github/commit-activity/y/skywind3000/z.lua)
- [tenfyzhong/z.nvim](https://github.com/tenfyzhong/z.nvim) ![](https://img.shields.io/github/stars/tenfyzhong/z.nvim) ![](https://img.shields.io/github/last-commit/tenfyzhong/z.nvim) ![](https://img.shields.io/github/commit-activity/y/tenfyzhong/z.nvim)

### ftdetect(Filetype detector)

- [spywhere/detect-language.nvim](https://github.com/spywhere/detect-language.nvim) ![](https://img.shields.io/github/stars/spywhere/detect-language.nvim) ![](https://img.shields.io/github/last-commit/spywhere/detect-language.nvim) ![](https://img.shields.io/github/commit-activity/y/spywhere/detect-language.nvim)

### ftplugin

- [prichrd/ftconf.nvim](https://github.com/prichrd/ftconf.nvim) ![](https://img.shields.io/github/stars/prichrd/ftconf.nvim) ![](https://img.shields.io/github/last-commit/prichrd/ftconf.nvim) ![](https://img.shields.io/github/commit-activity/y/prichrd/ftconf.nvim)

#### filetype colorscheme

- [folke/styler.nvim](https://github.com/folke/styler.nvim) ![](https://img.shields.io/github/stars/folke/styler.nvim) ![](https://img.shields.io/github/last-commit/folke/styler.nvim) ![](https://img.shields.io/github/commit-activity/y/folke/styler.nvim)

### Encoding

- [sjjwantfish/encodings.nvim](https://github.com/sjjwantfish/encodings.nvim) ![](https://img.shields.io/github/stars/sjjwantfish/encodings.nvim) ![](https://img.shields.io/github/last-commit/sjjwantfish/encodings.nvim) ![](https://img.shields.io/github/commit-activity/y/sjjwantfish/encodings.nvim)

### Macro

- [ecthelionvi/NeoComposer.nvim](https://github.com/ecthelionvi/NeoComposer.nvim) ![](https://img.shields.io/github/stars/ecthelionvi/NeoComposer.nvim) ![](https://img.shields.io/github/last-commit/ecthelionvi/NeoComposer.nvim) ![](https://img.shields.io/github/commit-activity/y/ecthelionvi/NeoComposer.nvim)
- [chrisgrieser/nvim-recorder](https://github.com/chrisgrieser/nvim-recorder) ![](https://img.shields.io/github/stars/chrisgrieser/nvim-recorder) ![](https://img.shields.io/github/last-commit/chrisgrieser/nvim-recorder) ![](https://img.shields.io/github/commit-activity/y/chrisgrieser/nvim-recorder)
- [kensleDev/persistent-macros.nvim](https://github.com/kensleDev/persistent-macros.nvim) ![](https://img.shields.io/github/stars/kensleDev/persistent-macros.nvim) ![](https://img.shields.io/github/last-commit/kensleDev/persistent-macros.nvim) ![](https://img.shields.io/github/commit-activity/y/kensleDev/persistent-macros.nvim)
- [bignos/bookmacro](https://github.com/bignos/bookmacro) ![](https://img.shields.io/github/stars/bignos/bookmacro) ![](https://img.shields.io/github/last-commit/bignos/bookmacro) ![](https://img.shields.io/github/commit-activity/y/bignos/bookmacro)
- [desdic/macrothis.nvim](https://github.com/desdic/macrothis.nvim) ![](https://img.shields.io/github/stars/desdic/macrothis.nvim) ![](https://img.shields.io/github/last-commit/desdic/macrothis.nvim) ![](https://img.shields.io/github/commit-activity/y/desdic/macrothis.nvim)
- [jake-stewart/recursive-macro.nvim](https://github.com/jake-stewart/recursive-macro.nvim) ![](https://img.shields.io/github/stars/jake-stewart/recursive-macro.nvim) ![](https://img.shields.io/github/last-commit/jake-stewart/recursive-macro.nvim) ![](https://img.shields.io/github/commit-activity/y/jake-stewart/recursive-macro.nvim)
- [1riz/telescope-macros.nvim](https://github.com/1riz/telescope-macros.nvim) ![](https://img.shields.io/github/stars/1riz/telescope-macros.nvim) ![](https://img.shields.io/github/last-commit/1riz/telescope-macros.nvim) ![](https://img.shields.io/github/commit-activity/y/1riz/telescope-macros.nvim)
- [jesseleite/nvim-macroni](https://github.com/jesseleite/nvim-macroni) ![](https://img.shields.io/github/stars/jesseleite/nvim-macroni) ![](https://img.shields.io/github/last-commit/jesseleite/nvim-macroni) ![](https://img.shields.io/github/commit-activity/y/jesseleite/nvim-macroni)
- [FredTheDino/ma-pur-ma.nvim](https://github.com/FredTheDino/ma-pur-ma.nvim) ![](https://img.shields.io/github/stars/FredTheDino/ma-pur-ma.nvim) ![](https://img.shields.io/github/last-commit/FredTheDino/ma-pur-ma.nvim) ![](https://img.shields.io/github/commit-activity/y/FredTheDino/ma-pur-ma.nvim)
- [kr40/nvim-macros](https://github.com/kr40/nvim-macros) ![](https://img.shields.io/github/stars/kr40/nvim-macros) ![](https://img.shields.io/github/last-commit/kr40/nvim-macros) ![](https://img.shields.io/github/commit-activity/y/kr40/nvim-macros)
- [alexjercan/macros.nvim](https://github.com/alexjercan/macros.nvim) ![](https://img.shields.io/github/stars/alexjercan/macros.nvim) ![](https://img.shields.io/github/last-commit/alexjercan/macros.nvim) ![](https://img.shields.io/github/commit-activity/y/alexjercan/macros.nvim)

### Errorformat

- [faergeek/neomakery.nvim](https://github.com/faergeek/neomakery.nvim) ![](https://img.shields.io/github/stars/faergeek/neomakery.nvim) ![](https://img.shields.io/github/last-commit/faergeek/neomakery.nvim) ![](https://img.shields.io/github/commit-activity/y/faergeek/neomakery.nvim)

### Message

- [AckslD/messages.nvim](https://github.com/AckslD/messages.nvim) ![](https://img.shields.io/github/stars/AckslD/messages.nvim) ![](https://img.shields.io/github/last-commit/AckslD/messages.nvim) ![](https://img.shields.io/github/commit-activity/y/AckslD/messages.nvim)
- [notomo/hlmsg.nvim](https://github.com/notomo/hlmsg.nvim) ![](https://img.shields.io/github/stars/notomo/hlmsg.nvim) ![](https://img.shields.io/github/last-commit/notomo/hlmsg.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/hlmsg.nvim)
- [ariel-frischer/bmessages.nvim](https://github.com/ariel-frischer/bmessages.nvim) ![](https://img.shields.io/github/stars/ariel-frischer/bmessages.nvim) ![](https://img.shields.io/github/last-commit/ariel-frischer/bmessages.nvim) ![](https://img.shields.io/github/commit-activity/y/ariel-frischer/bmessages.nvim)
- [OliverChao/bufmsg.nvim](https://github.com/OliverChao/bufmsg.nvim) ![](https://img.shields.io/github/stars/OliverChao/bufmsg.nvim) ![](https://img.shields.io/github/last-commit/OliverChao/bufmsg.nvim) ![](https://img.shields.io/github/commit-activity/y/OliverChao/bufmsg.nvim)

### [Help](./help.md)

### checkhealth

- [Davidyz/executable-checker.nvim](https://github.com/Davidyz/executable-checker.nvim) ![](https://img.shields.io/github/stars/Davidyz/executable-checker.nvim) ![](https://img.shields.io/github/last-commit/Davidyz/executable-checker.nvim) ![](https://img.shields.io/github/commit-activity/y/Davidyz/executable-checker.nvim)

### [Save&Backup](./save_backup.md)

### [Startup](./startup.md)

### [Session](./session.md)

### init.lua(vimrc)

- [Zeioth/distroupdate.nvim](https://github.com/Zeioth/distroupdate.nvim) ![](https://img.shields.io/github/stars/Zeioth/distroupdate.nvim) ![](https://img.shields.io/github/last-commit/Zeioth/distroupdate.nvim) ![](https://img.shields.io/github/commit-activity/y/Zeioth/distroupdate.nvim)

### Mouse

- [notomo/gesture.nvim](https://github.com/notomo/gesture.nvim) ![](https://img.shields.io/github/stars/notomo/gesture.nvim) ![](https://img.shields.io/github/last-commit/notomo/gesture.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/gesture.nvim)

### Profiler

- [mgerb/metrics.nvim](https://github.com/mgerb/metrics.nvim) ![](https://img.shields.io/github/stars/mgerb/metrics.nvim) ![](https://img.shields.io/github/last-commit/mgerb/metrics.nvim) ![](https://img.shields.io/github/commit-activity/y/mgerb/metrics.nvim)
- [wookayin/nvim-profiler](https://github.com/wookayin/nvim-profiler) ![](https://img.shields.io/github/stars/wookayin/nvim-profiler) ![](https://img.shields.io/github/last-commit/wookayin/nvim-profiler) ![](https://img.shields.io/github/commit-activity/y/wookayin/nvim-profiler)

## Coding

### Reading assistant feature

- [haringsrob/nvim_context_vt](https://github.com/haringsrob/nvim_context_vt) ![](https://img.shields.io/github/stars/haringsrob/nvim_context_vt) ![](https://img.shields.io/github/last-commit/haringsrob/nvim_context_vt) ![](https://img.shields.io/github/commit-activity/y/haringsrob/nvim_context_vt)
- [code-biscuits/nvim-biscuits](https://github.com/code-biscuits/nvim-biscuits) ![](https://img.shields.io/github/stars/code-biscuits/nvim-biscuits) ![](https://img.shields.io/github/last-commit/code-biscuits/nvim-biscuits) ![](https://img.shields.io/github/commit-activity/y/code-biscuits/nvim-biscuits)
- [loctvl842/breadcrumb.nvim](https://github.com/loctvl842/breadcrumb.nvim) ![](https://img.shields.io/github/stars/loctvl842/breadcrumb.nvim) ![](https://img.shields.io/github/last-commit/loctvl842/breadcrumb.nvim) ![](https://img.shields.io/github/commit-activity/y/loctvl842/breadcrumb.nvim)
- [KaitlynEthylia/TreePin](https://github.com/KaitlynEthylia/TreePin) ![](https://img.shields.io/github/stars/KaitlynEthylia/TreePin) ![](https://img.shields.io/github/last-commit/KaitlynEthylia/TreePin) ![](https://img.shields.io/github/commit-activity/y/KaitlynEthylia/TreePin)
- [Gelio/nvim-relative-date](https://github.com/Gelio/nvim-relative-date) ![](https://img.shields.io/github/stars/Gelio/nvim-relative-date) ![](https://img.shields.io/github/last-commit/Gelio/nvim-relative-date) ![](https://img.shields.io/github/commit-activity/y/Gelio/nvim-relative-date)

#### Current Position Info

- [delphinus/characterize.nvim](https://github.com/delphinus/characterize.nvim) ![](https://img.shields.io/github/stars/delphinus/characterize.nvim) ![](https://img.shields.io/github/last-commit/delphinus/characterize.nvim) ![](https://img.shields.io/github/commit-activity/y/delphinus/characterize.nvim)
- [diegoulloao/nvim-file-location](https://github.com/diegoulloao/nvim-file-location) ![](https://img.shields.io/github/stars/diegoulloao/nvim-file-location) ![](https://img.shields.io/github/last-commit/diegoulloao/nvim-file-location) ![](https://img.shields.io/github/commit-activity/y/diegoulloao/nvim-file-location)

### [Comment Out](./comment.md)

#### Context Header

- [polarmutex/contextprint.nvim](https://github.com/polarmutex/contextprint.nvim) ![](https://img.shields.io/github/stars/polarmutex/contextprint.nvim) ![](https://img.shields.io/github/last-commit/polarmutex/contextprint.nvim) ![](https://img.shields.io/github/commit-activity/y/polarmutex/contextprint.nvim)
- [romgrk/nvim-treesitter-context](https://github.com/romgrk/nvim-treesitter-context) ![](https://img.shields.io/github/stars/romgrk/nvim-treesitter-context) ![](https://img.shields.io/github/last-commit/romgrk/nvim-treesitter-context) ![](https://img.shields.io/github/commit-activity/y/romgrk/nvim-treesitter-context)

### [Linter / Formatter](./linter_formatter.md)

### Import

- [piersolenski/telescope-import.nvim](https://github.com/piersolenski/telescope-import.nvim) ![](https://img.shields.io/github/stars/piersolenski/telescope-import.nvim) ![](https://img.shields.io/github/last-commit/piersolenski/telescope-import.nvim) ![](https://img.shields.io/github/commit-activity/y/piersolenski/telescope-import.nvim)

### Regex

- [Djancyp/regex.nvim](https://github.com/Djancyp/regex.nvim) ![](https://img.shields.io/github/stars/Djancyp/regex.nvim) ![](https://img.shields.io/github/last-commit/Djancyp/regex.nvim) ![](https://img.shields.io/github/commit-activity/y/Djancyp/regex.nvim)
- [bennypowers/nvim-regexplainer](https://github.com/bennypowers/nvim-regexplainer) ![](https://img.shields.io/github/stars/bennypowers/nvim-regexplainer) ![](https://img.shields.io/github/last-commit/bennypowers/nvim-regexplainer) ![](https://img.shields.io/github/commit-activity/y/bennypowers/nvim-regexplainer)
- [tomiis4/Hypersonic.nvim](https://github.com/tomiis4/Hypersonic.nvim) ![](https://img.shields.io/github/stars/tomiis4/Hypersonic.nvim) ![](https://img.shields.io/github/last-commit/tomiis4/Hypersonic.nvim) ![](https://img.shields.io/github/commit-activity/y/tomiis4/Hypersonic.nvim)
- [jake-stewart/regex-vars.nvim](https://github.com/jake-stewart/regex-vars.nvim) ![](https://img.shields.io/github/stars/jake-stewart/regex-vars.nvim) ![](https://img.shields.io/github/last-commit/jake-stewart/regex-vars.nvim) ![](https://img.shields.io/github/commit-activity/y/jake-stewart/regex-vars.nvim)

### Generate documentation

- [Zeioth/dooku.nvim](https://github.com/Zeioth/dooku.nvim) ![](https://img.shields.io/github/stars/Zeioth/dooku.nvim) ![](https://img.shields.io/github/last-commit/Zeioth/dooku.nvim) ![](https://img.shields.io/github/commit-activity/y/Zeioth/dooku.nvim)

### [Code outline](./code-outline.md)

### [Snippet/Template](./snippet_template.md)

### [Task Runner](./task-runner.md)

### [Test](./test.md)

### [Debug/REPL](./debugger_repl.md)

### [Git/GitHub](./git-github.md)

### [Project](./project.md)

## New features

### [Note Taking](./note-taking.md)

### Diagram

- [jbyuki/venn.nvim](https://github.com/jbyuki/venn.nvim) ![](https://img.shields.io/github/stars/jbyuki/venn.nvim) ![](https://img.shields.io/github/last-commit/jbyuki/venn.nvim) ![](https://img.shields.io/github/commit-activity/y/jbyuki/venn.nvim)

### [Translate](./translate.md)

### Manual

- [loganswartz/updoc.nvim](https://github.com/loganswartz/updoc.nvim) ![](https://img.shields.io/github/stars/loganswartz/updoc.nvim) ![](https://img.shields.io/github/last-commit/loganswartz/updoc.nvim) ![](https://img.shields.io/github/commit-activity/y/loganswartz/updoc.nvim)

### Popup Info

- [lewis6991/hover.nvim](https://github.com/lewis6991/hover.nvim) ![](https://img.shields.io/github/stars/lewis6991/hover.nvim) ![](https://img.shields.io/github/last-commit/lewis6991/hover.nvim) ![](https://img.shields.io/github/commit-activity/y/lewis6991/hover.nvim)
- [ellisonleao/weather.nvim](https://github.com/ellisonleao/weather.nvim) ![](https://img.shields.io/github/stars/ellisonleao/weather.nvim) ![](https://img.shields.io/github/last-commit/ellisonleao/weather.nvim) ![](https://img.shields.io/github/commit-activity/y/ellisonleao/weather.nvim)
- [dgyurov/termify.nvim](https://github.com/dgyurov/termify.nvim) ![](https://img.shields.io/github/stars/dgyurov/termify.nvim) ![](https://img.shields.io/github/last-commit/dgyurov/termify.nvim) ![](https://img.shields.io/github/commit-activity/y/dgyurov/termify.nvim)
- [StonyBoy/nvim-update-time](https://github.com/StonyBoy/nvim-update-time) ![](https://img.shields.io/github/stars/StonyBoy/nvim-update-time) ![](https://img.shields.io/github/last-commit/StonyBoy/nvim-update-time) ![](https://img.shields.io/github/commit-activity/y/StonyBoy/nvim-update-time)
- [Fildo7525/pretty_hover](https://github.com/Fildo7525/pretty_hover) ![](https://img.shields.io/github/stars/Fildo7525/pretty_hover) ![](https://img.shields.io/github/last-commit/Fildo7525/pretty_hover) ![](https://img.shields.io/github/commit-activity/y/Fildo7525/pretty_hover)

### File Handling

- [chrisgrieser/nvim-ghengis](https://github.com/chrisgrieser/nvim-ghengis) ![](https://img.shields.io/github/stars/chrisgrieser/nvim-ghengis) ![](https://img.shields.io/github/last-commit/chrisgrieser/nvim-ghengis) ![](https://img.shields.io/github/commit-activity/y/chrisgrieser/nvim-ghengis)

### Command Palette

- [mrjones2014/legendary.nvim](https://github.com/mrjones2014/legendary.nvim) ![](https://img.shields.io/github/stars/mrjones2014/legendary.nvim) ![](https://img.shields.io/github/last-commit/mrjones2014/legendary.nvim) ![](https://img.shields.io/github/commit-activity/y/mrjones2014/legendary.nvim)
- [FeiyouG/command_center.nvim](https://github.com/FeiyouG/command_center.nvim) ![](https://img.shields.io/github/stars/FeiyouG/command_center.nvim) ![](https://img.shields.io/github/last-commit/FeiyouG/command_center.nvim) ![](https://img.shields.io/github/commit-activity/y/FeiyouG/command_center.nvim)
- [octarect/telescope-menu.nvim](https://github.com/octarect/telescope-menu.nvim) ![](https://img.shields.io/github/stars/octarect/telescope-menu.nvim) ![](https://img.shields.io/github/last-commit/octarect/telescope-menu.nvim) ![](https://img.shields.io/github/commit-activity/y/octarect/telescope-menu.nvim)
- [jvs/commanderly.nvim](https://github.com/jvs/commanderly.nvim) ![](https://img.shields.io/github/stars/jvs/commanderly.nvim) ![](https://img.shields.io/github/last-commit/jvs/commanderly.nvim) ![](https://img.shields.io/github/commit-activity/y/jvs/commanderly.nvim)
- [hachy/cmdpalette.nvim](https://github.com/hachy/cmdpalette.nvim) ![](https://img.shields.io/github/stars/hachy/cmdpalette.nvim) ![](https://img.shields.io/github/last-commit/hachy/cmdpalette.nvim) ![](https://img.shields.io/github/commit-activity/y/hachy/cmdpalette.nvim)
- [AtleSkaanes/command-palette.nvim](https://github.com/AtleSkaanes/command-palette.nvim) ![](https://img.shields.io/github/stars/AtleSkaanes/command-palette.nvim) ![](https://img.shields.io/github/last-commit/AtleSkaanes/command-palette.nvim) ![](https://img.shields.io/github/commit-activity/y/AtleSkaanes/command-palette.nvim)
- [Ajnasz/telescope-runcmd.nvim](https://github.com/Ajnasz/telescope-runcmd.nvim) ![](https://img.shields.io/github/stars/Ajnasz/telescope-runcmd.nvim) ![](https://img.shields.io/github/last-commit/Ajnasz/telescope-runcmd.nvim) ![](https://img.shields.io/github/commit-activity/y/Ajnasz/telescope-runcmd.nvim)
- [azatakmyradov/command.nvim](https://github.com/azatakmyradov/command.nvim) ![](https://img.shields.io/github/stars/azatakmyradov/command.nvim) ![](https://img.shields.io/github/last-commit/azatakmyradov/command.nvim) ![](https://img.shields.io/github/commit-activity/y/azatakmyradov/command.nvim)

### Reload Configuration

- [milkias17/reloader.nvim](https://github.com/milkias17/reloader.nvim) ![](https://img.shields.io/github/stars/milkias17/reloader.nvim) ![](https://img.shields.io/github/last-commit/milkias17/reloader.nvim) ![](https://img.shields.io/github/commit-activity/y/milkias17/reloader.nvim)
- [mskelton/live-reload.nvim](https://github.com/mskelton/live-reload.nvim) ![](https://img.shields.io/github/stars/mskelton/live-reload.nvim) ![](https://img.shields.io/github/last-commit/mskelton/live-reload.nvim) ![](https://img.shields.io/github/commit-activity/y/mskelton/live-reload.nvim)

### [Package Manager](./package-manager.md)

### Remote Development

- [chipsenkbeil/distant.nvim](https://github.com/chipsenkbeil/distant.nvim) ![](https://img.shields.io/github/stars/chipsenkbeil/distant.nvim) ![](https://img.shields.io/github/last-commit/chipsenkbeil/distant.nvim) ![](https://img.shields.io/github/commit-activity/y/chipsenkbeil/distant.nvim)
- [stefanwatt/remote.nvim](https://github.com/stefanwatt/remote.nvim) ![](https://img.shields.io/github/stars/stefanwatt/remote.nvim) ![](https://img.shields.io/github/last-commit/stefanwatt/remote.nvim) ![](https://img.shields.io/github/commit-activity/y/stefanwatt/remote.nvim)
- [amitds1997/remote-nvim.nvim](https://github.com/amitds1997/remote-nvim.nvim) ![](https://img.shields.io/github/stars/amitds1997/remote-nvim.nvim) ![](https://img.shields.io/github/last-commit/amitds1997/remote-nvim.nvim) ![](https://img.shields.io/github/commit-activity/y/amitds1997/remote-nvim.nvim)

### Devcontainer

- [jamestthompson3/nvim-remote-containers](https://github.com/jamestthompson3/nvim-remote-containers) ![](https://img.shields.io/github/stars/jamestthompson3/nvim-remote-containers) ![](https://img.shields.io/github/last-commit/jamestthompson3/nvim-remote-containers) ![](https://img.shields.io/github/commit-activity/y/jamestthompson3/nvim-remote-containers)
- [esensar/nvim-dev-container](https://github.com/esensar/nvim-dev-container) ![](https://img.shields.io/github/stars/esensar/nvim-dev-container) ![](https://img.shields.io/github/last-commit/esensar/nvim-dev-container) ![](https://img.shields.io/github/commit-activity/y/esensar/nvim-dev-container)
- [arnaupv/nvim-devcontainer-cli](https://github.com/arnaupv/nvim-devcontainer-cli) ![](https://img.shields.io/github/stars/arnaupv/nvim-devcontainer-cli) ![](https://img.shields.io/github/last-commit/arnaupv/nvim-devcontainer-cli) ![](https://img.shields.io/github/commit-activity/y/arnaupv/nvim-devcontainer-cli)
- [aw1875/devcontainers.nvim](https://github.com/aw1875/devcontainers.nvim) ![](https://img.shields.io/github/stars/aw1875/devcontainers.nvim) ![](https://img.shields.io/github/last-commit/aw1875/devcontainers.nvim) ![](https://img.shields.io/github/commit-activity/y/aw1875/devcontainers.nvim)

### Collaborative Editing

- [jbyuki/instant.nvim](https://github.com/jbyuki/instant.nvim) ![](https://img.shields.io/github/stars/jbyuki/instant.nvim) ![](https://img.shields.io/github/last-commit/jbyuki/instant.nvim) ![](https://img.shields.io/github/commit-activity/y/jbyuki/instant.nvim)
- [pkage/coauthor.nvim](https://github.com/pkage/coauthor.nvim) ![](https://img.shields.io/github/stars/pkage/coauthor.nvim) ![](https://img.shields.io/github/last-commit/pkage/coauthor.nvim) ![](https://img.shields.io/github/commit-activity/y/pkage/coauthor.nvim)

### [Image](./image.md)

### Notification

- [rcarriga/nvim-notify](https://github.com/rcarriga/nvim-notify) ![](https://img.shields.io/github/stars/rcarriga/nvim-notify) ![](https://img.shields.io/github/last-commit/rcarriga/nvim-notify) ![](https://img.shields.io/github/commit-activity/y/rcarriga/nvim-notify)
- [vigoux/notifier.nvim](https://github.com/vigoux/notifier.nvim) ![](https://img.shields.io/github/stars/vigoux/notifier.nvim) ![](https://img.shields.io/github/last-commit/vigoux/notifier.nvim) ![](https://img.shields.io/github/commit-activity/y/vigoux/notifier.nvim)
- [phaazon/notisys.nvim](https://github.com/phaazon/notisys.nvim) ![](https://img.shields.io/github/stars/phaazon/notisys.nvim) ![](https://img.shields.io/github/last-commit/phaazon/notisys.nvim) ![](https://img.shields.io/github/commit-activity/y/phaazon/notisys.nvim)
- [haolian9/zhiyuan.nvim](https://github.com/haolian9/zhiyuan.nvim) ![](https://img.shields.io/github/stars/haolian9/zhiyuan.nvim) ![](https://img.shields.io/github/last-commit/haolian9/zhiyuan.nvim) ![](https://img.shields.io/github/commit-activity/y/haolian9/zhiyuan.nvim)
- [waltr-fr/redalert.nvim](https://github.com/waltr-fr/redalert.nvim) ![](https://img.shields.io/github/stars/waltr-fr/redalert.nvim) ![](https://img.shields.io/github/last-commit/waltr-fr/redalert.nvim) ![](https://img.shields.io/github/commit-activity/y/waltr-fr/redalert.nvim)

### Schedule

- [Cassin01/sche.nvim](https://github.com/Cassin01/sche.nvim) ![](https://img.shields.io/github/stars/Cassin01/sche.nvim) ![](https://img.shields.io/github/last-commit/Cassin01/sche.nvim) ![](https://img.shields.io/github/commit-activity/y/Cassin01/sche.nvim)

### Key stroke

- [jerrywang1981/keystroke.nvim](https://github.com/jerrywang1981/keystroke.nvim) ![](https://img.shields.io/github/stars/jerrywang1981/keystroke.nvim) ![](https://img.shields.io/github/last-commit/jerrywang1981/keystroke.nvim) ![](https://img.shields.io/github/commit-activity/y/jerrywang1981/keystroke.nvim)

### [Concentration(Pomodoro/Zenn)](./concentration.md)

### Human-readable

- [chuck-flowers/purl.nvim](https://github.com/chuck-flowers/purl.nvim) ![](https://img.shields.io/github/stars/chuck-flowers/purl.nvim) ![](https://img.shields.io/github/last-commit/chuck-flowers/purl.nvim) ![](https://img.shields.io/github/commit-activity/y/chuck-flowers/purl.nvim)
- [asrul10/readable-number.nvim](https://github.com/asrul10/readable-number.nvim) ![](https://img.shields.io/github/stars/asrul10/readable-number.nvim) ![](https://img.shields.io/github/last-commit/asrul10/readable-number.nvim) ![](https://img.shields.io/github/commit-activity/y/asrul10/readable-number.nvim)

#### bionic reading

- [JellyApple102/easyread.nvim](https://github.com/JellyApple102/easyread.nvim) ![](https://img.shields.io/github/stars/JellyApple102/easyread.nvim) ![](https://img.shields.io/github/last-commit/JellyApple102/easyread.nvim) ![](https://img.shields.io/github/commit-activity/y/JellyApple102/easyread.nvim)
- [FluxxField/bionic-reading.nvim](https://github.com/FluxxField/bionic-reading.nvim) ![](https://img.shields.io/github/stars/FluxxField/bionic-reading.nvim) ![](https://img.shields.io/github/last-commit/FluxxField/bionic-reading.nvim) ![](https://img.shields.io/github/commit-activity/y/FluxxField/bionic-reading.nvim)
- [HampusHauffman/bionic.nvim](https://github.com/HampusHauffman/bionic.nvim) ![](https://img.shields.io/github/stars/HampusHauffman/bionic.nvim) ![](https://img.shields.io/github/last-commit/HampusHauffman/bionic.nvim) ![](https://img.shields.io/github/commit-activity/y/HampusHauffman/bionic.nvim)

### Scratchpad

- [FraserLee/ScratchPad](https://github.com/FraserLee/ScratchPad) ![](https://img.shields.io/github/stars/FraserLee/ScratchPad) ![](https://img.shields.io/github/last-commit/FraserLee/ScratchPad) ![](https://img.shields.io/github/commit-activity/y/FraserLee/ScratchPad)
- [sindrets/scratchpad.nvim](https://github.com/sindrets/scratchpad.nvim) ![](https://img.shields.io/github/stars/sindrets/scratchpad.nvim) ![](https://img.shields.io/github/last-commit/sindrets/scratchpad.nvim) ![](https://img.shields.io/github/commit-activity/y/sindrets/scratchpad.nvim)
- [niuiic/part-edit.nvim](https://github.com/niuiic/part-edit.nvim) ![](https://img.shields.io/github/stars/niuiic/part-edit.nvim) ![](https://img.shields.io/github/last-commit/niuiic/part-edit.nvim) ![](https://img.shields.io/github/commit-activity/y/niuiic/part-edit.nvim)
- [musaubrian/scratch.nvim](https://github.com/musaubrian/scratch.nvim) ![](https://img.shields.io/github/stars/musaubrian/scratch.nvim) ![](https://img.shields.io/github/last-commit/musaubrian/scratch.nvim) ![](https://img.shields.io/github/commit-activity/y/musaubrian/scratch.nvim)

### Performance Test

- [pseudocc/nvim-apm](https://github.com/pseudocc/nvim-apm) ![](https://img.shields.io/github/stars/pseudocc/nvim-apm) ![](https://img.shields.io/github/last-commit/pseudocc/nvim-apm) ![](https://img.shields.io/github/commit-activity/y/pseudocc/nvim-apm)

### Security

- [laytan/cloak.nvim](https://github.com/laytan/cloak.nvim) ![](https://img.shields.io/github/stars/laytan/cloak.nvim) ![](https://img.shields.io/github/last-commit/laytan/cloak.nvim) ![](https://img.shields.io/github/commit-activity/y/laytan/cloak.nvim)
- [kurotych/ccryptor.nvim](https://github.com/kurotych/ccryptor.nvim) ![](https://img.shields.io/github/stars/kurotych/ccryptor.nvim) ![](https://img.shields.io/github/last-commit/kurotych/ccryptor.nvim) ![](https://img.shields.io/github/commit-activity/y/kurotych/ccryptor.nvim)
- [roberte777/keep-it-secret.nvim](https://github.com/roberte777/keep-it-secret.nvim) ![](https://img.shields.io/github/stars/roberte777/keep-it-secret.nvim) ![](https://img.shields.io/github/last-commit/roberte777/keep-it-secret.nvim) ![](https://img.shields.io/github/commit-activity/y/roberte777/keep-it-secret.nvim)
- [Praczet/encrypt-text.nvim](https://github.com/Praczet/encrypt-text.nvim) ![](https://img.shields.io/github/stars/Praczet/encrypt-text.nvim) ![](https://img.shields.io/github/last-commit/Praczet/encrypt-text.nvim) ![](https://img.shields.io/github/commit-activity/y/Praczet/encrypt-text.nvim)
- [kode-team/vault.nvim](https://github.com/kode-team/vault.nvim) ![](https://img.shields.io/github/stars/kode-team/vault.nvim) ![](https://img.shields.io/github/last-commit/kode-team/vault.nvim) ![](https://img.shields.io/github/commit-activity/y/kode-team/vault.nvim)
- [Kolkhis/streamer-mode.nvim](https://github.com/Kolkhis/streamer-mode.nvim) ![](https://img.shields.io/github/stars/Kolkhis/streamer-mode.nvim) ![](https://img.shields.io/github/last-commit/Kolkhis/streamer-mode.nvim) ![](https://img.shields.io/github/commit-activity/y/Kolkhis/streamer-mode.nvim)
- [lucidph3nx/nvim-sops](https://github.com/lucidph3nx/nvim-sops) ![](https://img.shields.io/github/stars/lucidph3nx/nvim-sops) ![](https://img.shields.io/github/last-commit/lucidph3nx/nvim-sops) ![](https://img.shields.io/github/commit-activity/y/lucidph3nx/nvim-sops)
- [KingMichaelPark/age.nvim](https://github.com/KingMichaelPark/age.nvim) ![](https://img.shields.io/github/stars/KingMichaelPark/age.nvim) ![](https://img.shields.io/github/last-commit/KingMichaelPark/age.nvim) ![](https://img.shields.io/github/commit-activity/y/KingMichaelPark/age.nvim)
- [bgaillard/readonly.nvim](https://github.com/bgaillard/readonly.nvim) ![](https://img.shields.io/github/stars/bgaillard/readonly.nvim) ![](https://img.shields.io/github/last-commit/bgaillard/readonly.nvim) ![](https://img.shields.io/github/commit-activity/y/bgaillard/readonly.nvim)
- [GeekMasher/DevSecInspect.nvim](https://github.com/GeekMasher/DevSecInspect.nvim) ![](https://img.shields.io/github/stars/GeekMasher/DevSecInspect.nvim) ![](https://img.shields.io/github/last-commit/GeekMasher/DevSecInspect.nvim) ![](https://img.shields.io/github/commit-activity/y/GeekMasher/DevSecInspect.nvim)

#### Privacy

### Hex

#### Hex Editor

- [rktjmp/paperplanes.nvim](https://github.com/rktjmp/paperplanes.nvim) ![](https://img.shields.io/github/stars/rktjmp/paperplanes.nvim) ![](https://img.shields.io/github/last-commit/rktjmp/paperplanes.nvim) ![](https://img.shields.io/github/commit-activity/y/rktjmp/paperplanes.nvim)
- [RaafatTurki/hex.nvim](https://github.com/RaafatTurki/hex.nvim) ![](https://img.shields.io/github/stars/RaafatTurki/hex.nvim) ![](https://img.shields.io/github/last-commit/RaafatTurki/hex.nvim) ![](https://img.shields.io/github/commit-activity/y/RaafatTurki/hex.nvim)
- [vetsE/hexamine.nvim](https://github.com/vetsE/hexamine.nvim) ![](https://img.shields.io/github/stars/vetsE/hexamine.nvim) ![](https://img.shields.io/github/last-commit/vetsE/hexamine.nvim) ![](https://img.shields.io/github/commit-activity/y/vetsE/hexamine.nvim)

### Mail

- [martineausimon/nvim-mail-merge](https://github.com/martineausimon/nvim-mail-merge) ![](https://img.shields.io/github/stars/martineausimon/nvim-mail-merge) ![](https://img.shields.io/github/last-commit/martineausimon/nvim-mail-merge) ![](https://img.shields.io/github/commit-activity/y/martineausimon/nvim-mail-merge)
- [dnebauer/dn-mail.nvim](https://github.com/dnebauer/dn-mail.nvim) ![](https://img.shields.io/github/stars/dnebauer/dn-mail.nvim) ![](https://img.shields.io/github/last-commit/dnebauer/dn-mail.nvim) ![](https://img.shields.io/github/commit-activity/y/dnebauer/dn-mail.nvim)

### Calendar

- [gaoDean/cal.nvim](https://github.com/gaoDean/cal.nvim) ![](https://img.shields.io/github/stars/gaoDean/cal.nvim) ![](https://img.shields.io/github/last-commit/gaoDean/cal.nvim) ![](https://img.shields.io/github/commit-activity/y/gaoDean/cal.nvim)
- [ds1sqe/Calendar.nvim](https://github.com/ds1sqe/Calendar.nvim) ![](https://img.shields.io/github/stars/ds1sqe/Calendar.nvim) ![](https://img.shields.io/github/last-commit/ds1sqe/Calendar.nvim) ![](https://img.shields.io/github/commit-activity/y/ds1sqe/Calendar.nvim)
- [aPeoplesCalendar/apc.nvim](https://github.com/aPeoplesCalendar/apc.nvim) ![](https://img.shields.io/github/stars/aPeoplesCalendar/apc.nvim) ![](https://img.shields.io/github/last-commit/aPeoplesCalendar/apc.nvim) ![](https://img.shields.io/github/commit-activity/y/aPeoplesCalendar/apc.nvim)
- [lutzzdias/calendrum.nvim](https://github.com/lutzzdias/calendrum.nvim) ![](https://img.shields.io/github/stars/lutzzdias/calendrum.nvim) ![](https://img.shields.io/github/last-commit/lutzzdias/calendrum.nvim) ![](https://img.shields.io/github/commit-activity/y/lutzzdias/calendrum.nvim)

### Presentation

- [Chaitanyabsprip/present.nvim](https://github.com/Chaitanyabsprip/present.nvim) ![](https://img.shields.io/github/stars/Chaitanyabsprip/present.nvim) ![](https://img.shields.io/github/last-commit/Chaitanyabsprip/present.nvim) ![](https://img.shields.io/github/commit-activity/y/Chaitanyabsprip/present.nvim)
- [sotte/presenting.nvim](https://github.com/sotte/presenting.nvim) ![](https://img.shields.io/github/stars/sotte/presenting.nvim) ![](https://img.shields.io/github/last-commit/sotte/presenting.nvim) ![](https://img.shields.io/github/commit-activity/y/sotte/presenting.nvim)

### EDITOR

- [notomo/waitevent.nvim](https://github.com/notomo/waitevent.nvim) ![](https://img.shields.io/github/stars/notomo/waitevent.nvim) ![](https://img.shields.io/github/last-commit/notomo/waitevent.nvim) ![](https://img.shields.io/github/commit-activity/y/notomo/waitevent.nvim)

### Tutorial

- [antonk52/bad-practices.nvim](https://github.com/antonk52/bad-practices.nvim) ![](https://img.shields.io/github/stars/antonk52/bad-practices.nvim) ![](https://img.shields.io/github/last-commit/antonk52/bad-practices.nvim) ![](https://img.shields.io/github/commit-activity/y/antonk52/bad-practices.nvim)
- [xiantang/coach.nvim](https://github.com/xiantang/coach.nvim) ![](https://img.shields.io/github/stars/xiantang/coach.nvim) ![](https://img.shields.io/github/last-commit/xiantang/coach.nvim) ![](https://img.shields.io/github/commit-activity/y/xiantang/coach.nvim)
- [Ernest1338/training.nvim](https://github.com/Ernest1338/training.nvim) ![](https://img.shields.io/github/stars/Ernest1338/training.nvim) ![](https://img.shields.io/github/last-commit/Ernest1338/training.nvim) ![](https://img.shields.io/github/commit-activity/y/Ernest1338/training.nvim)

### Analytics

- [diego-rapoport/wt.nvim](https://github.com/diego-rapoport/wt.nvim) ![](https://img.shields.io/github/stars/diego-rapoport/wt.nvim) ![](https://img.shields.io/github/last-commit/diego-rapoport/wt.nvim) ![](https://img.shields.io/github/commit-activity/y/diego-rapoport/wt.nvim)
- [rohanorton/mytime.nvim](https://github.com/rohanorton/mytime.nvim) ![](https://img.shields.io/github/stars/rohanorton/mytime.nvim) ![](https://img.shields.io/github/last-commit/rohanorton/mytime.nvim) ![](https://img.shields.io/github/commit-activity/y/rohanorton/mytime.nvim)
- [gaborvecsei/usage-tracker.nvim](https://github.com/gaborvecsei/usage-tracker.nvim) ![](https://img.shields.io/github/stars/gaborvecsei/usage-tracker.nvim) ![](https://img.shields.io/github/last-commit/gaborvecsei/usage-tracker.nvim) ![](https://img.shields.io/github/commit-activity/y/gaborvecsei/usage-tracker.nvim)
- [mvllow/stand.nvim](https://github.com/mvllow/stand.nvim) ![](https://img.shields.io/github/stars/mvllow/stand.nvim) ![](https://img.shields.io/github/last-commit/mvllow/stand.nvim) ![](https://img.shields.io/github/commit-activity/y/mvllow/stand.nvim)
- [kimpors/progress.nvim](https://github.com/kimpors/progress.nvim) ![](https://img.shields.io/github/stars/kimpors/progress.nvim) ![](https://img.shields.io/github/last-commit/kimpors/progress.nvim) ![](https://img.shields.io/github/commit-activity/y/kimpors/progress.nvim)
- [Lamby777/timewasted.nvim](https://github.com/Lamby777/timewasted.nvim) ![](https://img.shields.io/github/stars/Lamby777/timewasted.nvim) ![](https://img.shields.io/github/last-commit/Lamby777/timewasted.nvim) ![](https://img.shields.io/github/commit-activity/y/Lamby777/timewasted.nvim)
- [OscarCreator/keystats.nvim](https://github.com/OscarCreator/keystats.nvim) ![](https://img.shields.io/github/stars/OscarCreator/keystats.nvim) ![](https://img.shields.io/github/last-commit/OscarCreator/keystats.nvim) ![](https://img.shields.io/github/commit-activity/y/OscarCreator/keystats.nvim)
- [FriedemannG/klog.nvim](https://github.com/FriedemannG/klog.nvim) ![](https://img.shields.io/github/stars/FriedemannG/klog.nvim) ![](https://img.shields.io/github/last-commit/FriedemannG/klog.nvim) ![](https://img.shields.io/github/commit-activity/y/FriedemannG/klog.nvim)
- [rymdlego/readtime.nvim](https://github.com/rymdlego/readtime.nvim) ![](https://img.shields.io/github/stars/rymdlego/readtime.nvim) ![](https://img.shields.io/github/last-commit/rymdlego/readtime.nvim) ![](https://img.shields.io/github/commit-activity/y/rymdlego/readtime.nvim)
- [Forsigg/daily-symbols-count.nvim](https://github.com/Forsigg/daily-symbols-count.nvim) ![](https://img.shields.io/github/stars/Forsigg/daily-symbols-count.nvim) ![](https://img.shields.io/github/last-commit/Forsigg/daily-symbols-count.nvim) ![](https://img.shields.io/github/commit-activity/y/Forsigg/daily-symbols-count.nvim)
- [lincore81/zeitraum.nvim](https://github.com/lincore81/zeitraum.nvim) ![](https://img.shields.io/github/stars/lincore81/zeitraum.nvim) ![](https://img.shields.io/github/last-commit/lincore81/zeitraum.nvim) ![](https://img.shields.io/github/commit-activity/y/lincore81/zeitraum.nvim)
- [wjorden/focus-tracker.nvim](https://github.com/wjorden/focus-tracker.nvim) ![](https://img.shields.io/github/stars/wjorden/focus-tracker.nvim) ![](https://img.shields.io/github/last-commit/wjorden/focus-tracker.nvim) ![](https://img.shields.io/github/commit-activity/y/wjorden/focus-tracker.nvim)

#### Typing speed

- [JakobSachs/typing-metrics.nvim](https://github.com/JakobSachs/typing-metrics.nvim) ![](https://img.shields.io/github/stars/JakobSachs/typing-metrics.nvim) ![](https://img.shields.io/github/last-commit/JakobSachs/typing-metrics.nvim) ![](https://img.shields.io/github/commit-activity/y/JakobSachs/typing-metrics.nvim)

### Market place

- [tamton-aquib/nvim-market](https://github.com/tamton-aquib/nvim-market) ![](https://img.shields.io/github/stars/tamton-aquib/nvim-market) ![](https://img.shields.io/github/last-commit/tamton-aquib/nvim-market) ![](https://img.shields.io/github/commit-activity/y/tamton-aquib/nvim-market)
- [roobert/activate.nvim](https://github.com/roobert/activate.nvim) ![](https://img.shields.io/github/stars/roobert/activate.nvim) ![](https://img.shields.io/github/last-commit/roobert/activate.nvim) ![](https://img.shields.io/github/commit-activity/y/roobert/activate.nvim)

### RSS

- [pawemix/decscribe.nvim](https://github.com/pawemix/decscribe.nvim) ![](https://img.shields.io/github/stars/pawemix/decscribe.nvim) ![](https://img.shields.io/github/last-commit/pawemix/decscribe.nvim) ![](https://img.shields.io/github/commit-activity/y/pawemix/decscribe.nvim)

### IDE feature

- [AbaoFromCUG/intergrater.nvim](https://github.com/AbaoFromCUG/intergrater.nvim) ![](https://img.shields.io/github/stars/AbaoFromCUG/intergrater.nvim) ![](https://img.shields.io/github/last-commit/AbaoFromCUG/intergrater.nvim) ![](https://img.shields.io/github/commit-activity/y/AbaoFromCUG/intergrater.nvim)

#### Code::Stats

- [maorun/code-stats.nvim](https://github.com/maorun/code-stats.nvim) ![](https://img.shields.io/github/stars/maorun/code-stats.nvim) ![](https://img.shields.io/github/last-commit/maorun/code-stats.nvim) ![](https://img.shields.io/github/commit-activity/y/maorun/code-stats.nvim)
- [liljaylj/codestats.nvim](https://github.com/liljaylj/codestats.nvim) ![](https://img.shields.io/github/stars/liljaylj/codestats.nvim) ![](https://img.shields.io/github/last-commit/liljaylj/codestats.nvim) ![](https://img.shields.io/github/commit-activity/y/liljaylj/codestats.nvim)

### Update check

- [diegoroccia/checkupdate.nvim](https://github.com/diegoroccia/checkupdate.nvim) ![](https://img.shields.io/github/stars/diegoroccia/checkupdate.nvim) ![](https://img.shields.io/github/last-commit/diegoroccia/checkupdate.nvim) ![](https://img.shields.io/github/commit-activity/y/diegoroccia/checkupdate.nvim)

### Font

- [delphinus/eaw.nvim](https://github.com/delphinus/eaw.nvim) ![](https://img.shields.io/github/stars/delphinus/eaw.nvim) ![](https://img.shields.io/github/last-commit/delphinus/eaw.nvim) ![](https://img.shields.io/github/commit-activity/y/delphinus/eaw.nvim)
- [delphinus/cellwidths.nvim](https://github.com/delphinus/cellwidths.nvim) ![](https://img.shields.io/github/stars/delphinus/cellwidths.nvim) ![](https://img.shields.io/github/last-commit/delphinus/cellwidths.nvim) ![](https://img.shields.io/github/commit-activity/y/delphinus/cellwidths.nvim)
- [amarakon/nvim-cmp-fonts](https://github.com/amarakon/nvim-cmp-fonts) ![](https://img.shields.io/github/stars/amarakon/nvim-cmp-fonts) ![](https://img.shields.io/github/last-commit/amarakon/nvim-cmp-fonts) ![](https://img.shields.io/github/commit-activity/y/amarakon/nvim-cmp-fonts)
- [NycRat/gui-fonts.nvim](https://github.com/NycRat/gui-fonts.nvim) ![](https://img.shields.io/github/stars/NycRat/gui-fonts.nvim) ![](https://img.shields.io/github/last-commit/NycRat/gui-fonts.nvim) ![](https://img.shields.io/github/commit-activity/y/NycRat/gui-fonts.nvim)
- [allvpv/resize-font.nvim](https://github.com/allvpv/resize-font.nvim) ![](https://img.shields.io/github/stars/allvpv/resize-font.nvim) ![](https://img.shields.io/github/last-commit/allvpv/resize-font.nvim) ![](https://img.shields.io/github/commit-activity/y/allvpv/resize-font.nvim)
- [nvimdev/nerdicons.nvim](https://github.com/nvimdev/nerdicons.nvim) ![](https://img.shields.io/github/stars/nvimdev/nerdicons.nvim) ![](https://img.shields.io/github/last-commit/nvimdev/nerdicons.nvim) ![](https://img.shields.io/github/commit-activity/y/nvimdev/nerdicons.nvim)
- [tetzng/telescope-cica-icons.nvim](https://github.com/tetzng/telescope-cica-icons.nvim) ![](https://img.shields.io/github/stars/tetzng/telescope-cica-icons.nvim) ![](https://img.shields.io/github/last-commit/tetzng/telescope-cica-icons.nvim) ![](https://img.shields.io/github/commit-activity/y/tetzng/telescope-cica-icons.nvim)
- [dullmode/bye-nerdfont.nvim](https://github.com/dullmode/bye-nerdfont.nvim) ![](https://img.shields.io/github/stars/dullmode/bye-nerdfont.nvim) ![](https://img.shields.io/github/last-commit/dullmode/bye-nerdfont.nvim) ![](https://img.shields.io/github/commit-activity/y/dullmode/bye-nerdfont.nvim)
- [abcdefg233/fontresizer.nvim](https://github.com/abcdefg233/fontresizer.nvim) ![](https://img.shields.io/github/stars/abcdefg233/fontresizer.nvim) ![](https://img.shields.io/github/last-commit/abcdefg233/fontresizer.nvim) ![](https://img.shields.io/github/commit-activity/y/abcdefg233/fontresizer.nvim)

### [Emoji](./emoji.md)

### Keyboard Layout

- [kbario/homerows.nvim](https://github.com/kbario/homerows.nvim) ![](https://img.shields.io/github/stars/kbario/homerows.nvim) ![](https://img.shields.io/github/last-commit/kbario/homerows.nvim) ![](https://img.shields.io/github/commit-activity/y/kbario/homerows.nvim)
- [vetsE/bepo.nvim](https://github.com/vetsE/bepo.nvim) ![](https://img.shields.io/github/stars/vetsE/bepo.nvim) ![](https://img.shields.io/github/last-commit/vetsE/bepo.nvim) ![](https://img.shields.io/github/commit-activity/y/vetsE/bepo.nvim)
- [ivanesmantovich/xkbswitch.nvim](https://github.com/ivanesmantovich/xkbswitch.nvim) ![](https://img.shields.io/github/stars/ivanesmantovich/xkbswitch.nvim) ![](https://img.shields.io/github/last-commit/ivanesmantovich/xkbswitch.nvim) ![](https://img.shields.io/github/commit-activity/y/ivanesmantovich/xkbswitch.nvim)
- [nativerv/cyrillic.nvim](https://github.com/nativerv/cyrillic.nvim) ![](https://img.shields.io/github/stars/nativerv/cyrillic.nvim) ![](https://img.shields.io/github/last-commit/nativerv/cyrillic.nvim) ![](https://img.shields.io/github/commit-activity/y/nativerv/cyrillic.nvim)
- [jaredmontoya/bikey.nvim](https://github.com/jaredmontoya/bikey.nvim) ![](https://img.shields.io/github/stars/jaredmontoya/bikey.nvim) ![](https://img.shields.io/github/last-commit/jaredmontoya/bikey.nvim) ![](https://img.shields.io/github/commit-activity/y/jaredmontoya/bikey.nvim)

## Util pack

- [tamton-aquib/essentials.nvim](https://github.com/tamton-aquib/essentials.nvim) ![](https://img.shields.io/github/stars/tamton-aquib/essentials.nvim) ![](https://img.shields.io/github/last-commit/tamton-aquib/essentials.nvim) ![](https://img.shields.io/github/commit-activity/y/tamton-aquib/essentials.nvim)
- [tamton-aquib/stuff.nvim](https://github.com/tamton-aquib/stuff.nvim) ![](https://img.shields.io/github/stars/tamton-aquib/stuff.nvim) ![](https://img.shields.io/github/last-commit/tamton-aquib/stuff.nvim) ![](https://img.shields.io/github/commit-activity/y/tamton-aquib/stuff.nvim)
- [echasnovski/mini.misc](https://github.com/echasnovski/mini.misc) ![](https://img.shields.io/github/stars/echasnovski/mini.misc) ![](https://img.shields.io/github/last-commit/echasnovski/mini.misc) ![](https://img.shields.io/github/commit-activity/y/echasnovski/mini.misc)
- [altermo/small.nvim](https://github.com/altermo/small.nvim) ![](https://img.shields.io/github/stars/altermo/small.nvim) ![](https://img.shields.io/github/last-commit/altermo/small.nvim) ![](https://img.shields.io/github/commit-activity/y/altermo/small.nvim)
- [enigmaiiiiiiii/mini-functions.nvim](https://github.com/enigmaiiiiiiii/mini-functions.nvim) ![](https://img.shields.io/github/stars/enigmaiiiiiiii/mini-functions.nvim) ![](https://img.shields.io/github/last-commit/enigmaiiiiiiii/mini-functions.nvim) ![](https://img.shields.io/github/commit-activity/y/enigmaiiiiiiii/mini-functions.nvim)
- [zegabr/toolbox.nvim](https://github.com/zegabr/toolbox.nvim) ![](https://img.shields.io/github/stars/zegabr/toolbox.nvim) ![](https://img.shields.io/github/last-commit/zegabr/toolbox.nvim) ![](https://img.shields.io/github/commit-activity/y/zegabr/toolbox.nvim)
- [Kicamon/tool.nvim](https://github.com/Kicamon/tool.nvim) ![](https://img.shields.io/github/stars/Kicamon/tool.nvim) ![](https://img.shields.io/github/last-commit/Kicamon/tool.nvim) ![](https://img.shields.io/github/commit-activity/y/Kicamon/tool.nvim)

## Patch

- [EtiamNullam/deferred-clipboard.nvim](https://github.com/EtiamNullam/deferred-clipboard.nvim) ![](https://img.shields.io/github/stars/EtiamNullam/deferred-clipboard.nvim) ![](https://img.shields.io/github/last-commit/EtiamNullam/deferred-clipboard.nvim) ![](https://img.shields.io/github/commit-activity/y/EtiamNullam/deferred-clipboard.nvim)
- [tanchihpin0517/cursorhold-timeout.nvim](https://github.com/tanchihpin0517/cursorhold-timeout.nvim) ![](https://img.shields.io/github/stars/tanchihpin0517/cursorhold-timeout.nvim) ![](https://img.shields.io/github/last-commit/tanchihpin0517/cursorhold-timeout.nvim) ![](https://img.shields.io/github/commit-activity/y/tanchihpin0517/cursorhold-timeout.nvim)
- [BranimirE/fix-auto-scroll.nvim](https://github.com/BranimirE/fix-auto-scroll.nvim) ![](https://img.shields.io/github/stars/BranimirE/fix-auto-scroll.nvim) ![](https://img.shields.io/github/last-commit/BranimirE/fix-auto-scroll.nvim) ![](https://img.shields.io/github/commit-activity/y/BranimirE/fix-auto-scroll.nvim)
- [4513ECHO/treesitter-compat-highlights.nvim](https://github.com/4513ECHO/treesitter-compat-highlights.nvim) ![](https://img.shields.io/github/stars/4513ECHO/treesitter-compat-highlights.nvim) ![](https://img.shields.io/github/last-commit/4513ECHO/treesitter-compat-highlights.nvim) ![](https://img.shields.io/github/commit-activity/y/4513ECHO/treesitter-compat-highlights.nvim)

## [Integration with other apps](./integration-apps.md)

### [Web Service](./web-service.md)

### [CLI](./cli.md)

### [AI](./ai.md)

### [OS](./os.md)

### [Hardware](./hardware.md)

## [Language specific](./language-specific.md)

### [Javascript/Typescript](./js_ts.md)

### [Python](./python.md)

### [C/C++](./c_cpp.md)

### [Go](./go.md)

## [Configuration File](./configration-file.md)

## [Documentation](./documentation.md)

## [Neovim Lua Library](./neovim-lua-library.md)

## [Neovim Lua Development](./neovim-lua-development.md)

## [Colorscheme](./colorscheme.md)

## [Neovim Distribution](./neovim-distribution.md)

## [GUI](./gui.md)

## [External Tools](./external-tools.md)

## [Service](./service.md)

## [Toy](./toy.md)
